# CLAUDE.md - LLM Platform Documentation Site

## Project Overview
A Docusaurus-based documentation site for the LLM Platform ecosystem. Aggregates documentation from all projects and provides unified API documentation, guides, and examples.

## Key Features
- **Unified Documentation**: Centralizes docs from all LLM Platform projects
- **API Documentation**: Auto-generated from OpenAPI specifications
- **Interactive Examples**: Live code samples and tutorials
- **Search Integration**: Full-text search across all documentation

## Development Commands
```bash
npm install                 # Install Docusaurus dependencies
npm start                   # Start development server
npm run build              # Build static documentation site
npm run serve              # Serve built documentation
npm run clear              # Clear Docusaurus cache
```

## Content Structure
- `docs/`: Main documentation content in Markdown
- `blog/`: Blog posts and announcements
- `src/`: Custom React components and pages
- `static/`: Static assets (images, files)
- `sidebars.js`: Navigation structure configuration

## Documentation Sources
- Aggregates README files from all LLM Platform projects
- OpenAPI specifications converted to documentation
- Hand-written guides and tutorials
- Code examples and sample implementations

## Build Process
- **Content Aggregation**: Scripts collect docs from source projects
- **API Doc Generation**: OpenAPI specs converted to interactive docs
- **Static Site Generation**: Docusaurus builds optimized static site
- **Search Indexing**: Full-text search index generation

## Automation Scripts
- `scripts/aggregate-docs.js`: Collects documentation from all projects
- `scripts/sync-project-docs.js`: Syncs project-specific documentation
- `scripts/validate-docs.js`: Validates documentation consistency
- `scripts/update-docs-structure.js`: Maintains navigation structure

## Content Guidelines
- Use clear, concise language
- Include practical code examples
- Maintain consistent formatting
- Link between related concepts
- Keep content up-to-date with code changes

## Deployment
- **Static Site**: Builds to static HTML/CSS/JS
- **Hosting**: Can be deployed to any static hosting service
- **CDN Integration**: Optimized for content delivery networks
- **Search**: Client-side search with pre-built index

## Maintenance
- Regular sync with source project documentation
- Validation of external links and references
- Update navigation when new projects are added
- Monitor for broken documentation links