# LLM Docs - Documentation Hub

A Docusaurus-based documentation site for the LLM Platform ecosystem. This is not a documentation generator, but rather a centralized documentation website.

**Status**: ✅ Active - v0.1.4
**Technology**: Docusaurus 3.x, React, JavaScript

## What This Actually Is

This project is a **Docusaurus documentation website** that serves as a central hub for LLM Platform documentation. It aggregates and displays documentation from various projects in the ecosystem.

## Current Implementation

### What's Actually Built
- Standard Docusaurus 3.x site configuration
- Basic homepage with React components
- Documentation aggregation scripts that collect markdown files from other projects
- Simple project sync utilities
- Sidebar navigation configuration
- Custom CSS styling

### Scripts Available
- `aggregate-docs.js` - Collects documentation from other projects
- `sync-project-docs.js` - Syncs documentation between projects
- `validate-docs.js` - Basic validation of documentation files
- Various migration and consolidation utilities

### What It Does NOT Do
- ❌ Does NOT generate documentation from source code
- ❌ Does NOT parse TypeScript/JavaScript files
- ❌ Does NOT process OpenAPI specifications
- ❌ Does NOT have a plugin system
- ❌ Does NOT export to PDF/DOCX
- ❌ Is NOT a documentation generator tool

## Installation

```bash
# Clone the repository
git clone <repository>
cd llm-docs

# Install dependencies
npm install

# Start development server
npm run dev
# or
npm start
```

## Usage

### Running the Documentation Site

```bash
# Development mode
npm run dev

# Build for production
npm run build

# Serve production build
npm run serve

# Aggregate documentation from other projects
npm run aggregate-docs

# Sync documentation updates
npm run sync-docs

# Validate documentation
npm run validate-docs
```

### Actual Documentation Structure

```
docs/
├── api/                    # API documentation (manually written)
├── architecture/           # Architecture docs (manually written)
├── cicd/                  # CI/CD documentation
├── packages/              # Package-specific docs (aggregated)
├── modules/               # Module documentation
└── various other dirs...  # Other manual documentation
```

## Configuration

The site is configured through `docusaurus.config.js` which defines:
- Site metadata and URLs
- Navigation structure
- Theme configuration
- Documentation paths
- Excluded files

No additional configuration files are needed or supported.

## Project Structure

```
llm-docs/
├── src/
│   ├── components/     # React components for Docusaurus
│   ├── css/           # Custom styling
│   ├── pages/         # Custom pages
│   └── services/      # Documentation aggregation services
├── docs/              # Actual documentation content
├── scripts/           # Utility scripts for doc management
├── static/            # Static assets
└── docusaurus.config.js # Site configuration
```

## How It Works

1. **Documentation Aggregation**: Scripts in the `scripts/` directory can collect markdown files from other projects in the LLM ecosystem
2. **Docusaurus Processing**: The collected documentation is processed by Docusaurus
3. **Static Site Generation**: Docusaurus builds a static website from the markdown files
4. **Deployment**: The built site can be deployed to any static hosting service

## Development

```bash
# Install dependencies
npm install

# Run tests (basic Jest tests only)
npm test

# Type checking
npm run typecheck

# Build for production
npm run build

# Development mode with hot reload
npm run dev
```

## Scripts

Key utility scripts in the `scripts/` directory:
- `aggregate-docs.js` - Aggregates documentation from multiple sources
- `sync-project-docs.js` - Syncs documentation between projects
- `validate-docs.js` - Validates documentation structure
- `migrate-to-docusaurus.js` - Helps migrate docs to Docusaurus format

## Current State

This is a functional Docusaurus site that serves as a documentation hub. It's actively used but is essentially a standard Docusaurus installation with some custom aggregation scripts.

### What Works
- ✅ Docusaurus site runs and builds
- ✅ Documentation aggregation from other projects
- ✅ Basic navigation and search (Docusaurus built-in)
- ✅ Dark mode support (Docusaurus built-in)
- ✅ Responsive design (Docusaurus built-in)

### Known Issues
- Documentation aggregation scripts may need manual intervention
- No automated documentation generation from code
- Limited test coverage
- Some broken internal links due to documentation moves

## Contributing

1. Write or update documentation in markdown
2. Place files in appropriate directories under `docs/`
3. Run `npm run validate-docs` to check for issues
4. Submit pull requests with documentation updates

## License

MIT 