export default {
  title: 'Bluefly Platform Documentation',
  description: 'Technical documentation for the Bluefly Platform',
  base: '/bfdocs/', // For GitLab Pages
  bundler: '@vuepress/bundler-vite',
  theme: '@vuepress/theme-default',
  head: [
    ['link', { rel: 'icon', href: '/favicon.ico' }],
    ['meta', { name: 'theme-color', content: '#3eaf7c' }],
    ['meta', { name: 'apple-mobile-web-app-capable', content: 'yes' }],
    ['meta', { name: 'apple-mobile-web-app-status-bar-style', content: 'black' }]
  ],
  themeConfig: {
    logo: '/logo.png',
    repo: 'gitlab.bluefly.io/ecosystem/bfdocs',
    docsDir: 'docs',
    editLinks: true,
    editLinkText: 'Edit this page on GitLab',
    lastUpdated: 'Last Updated',
    nav: [
      { text: 'Home', link: '/' },
      { text: 'Getting Started', link: '/getting-started/' },
      { text: 'Projects', link: '/projects/' },
      { text: 'Architecture', link: '/architecture/' },
      { text: 'Guides', link: '/guides/' },
      { text: 'API', link: '/api/' },
      { text: 'GitLab', link: 'https://gitlab.bluefly.io/ecosystem' }
    ],
    sidebar: {
      '/getting-started/': [
        {
          title: 'Getting Started',
          collapsable: false,
          children: [
            '',
            'installation',
            'quickstart'
          ]
        }
      ],
      '/projects/': [
        {
          title: 'Project Documentation',
          collapsable: false,
          children: [
            '',
            {
              title: 'Core Services',
              children: [
                'bfapi',
                'bfllm',
                'llm-mcp'
              ]
            },
            {
              title: 'Developer Tools',
              children: [
                'llmcli',
                'bfcicomponents'
              ]
            },
            {
              title: 'Frontend & SDKs',
              children: [
                'llm-ui',
                'llm-gateway-sdk',
                'bfrfp'
              ]
            },
            {
              title: 'Integration',
              children: [
                '_DrupalModules',
                'unified-compliance'
              ]
            }
          ]
        }
      ],
      '/architecture/': [
        {
          title: 'Architecture',
          collapsable: false,
          children: [
            '',
            'overview',
            'components',
            'integration',
            'deployment',
            'security',
            'resilience'
          ]
        }
      ],
      '/guides/': [
        {
          title: 'Implementation Guides',
          collapsable: false,
          children: [
            '',
            'IMPLEMENTATION_TEMPLATES',
            'NATIVE_INTEGRATION_METHODOLOGY',
            'SHARED_UTILITIES_MIGRATION_GUIDE',
            'VALIDATION_MIGRATION_GUIDE',
            'private-llm-implementation'
          ]
        }
      ],
      '/development/': [
        {
          title: 'Development',
          collapsable: false,
          children: [
            '',
            'best-practices',
            'standard',
            'testing',
            'workflows',
            'tdd/'
          ]
        }
      ],
      '/operations/': [
        {
          title: 'Operations',
          collapsable: false,
          children: [
            '',
            'deployment/',
            'monitoring/',
            'security/',
            'performance/'
          ]
        }
      ],
      '/api/': [
        {
          title: 'API Reference',
          collapsable: false,
          children: [
            '',
            'rest',
            'graphql',
            'gateway',
            'rate-limiting',
            'testing'
          ]
        }
      ],
      '/integration/': [
        {
          title: 'Integration',
          collapsable: false,
          children: [
            '',
            'patterns',
            'drupal/',
            'shared-utilities',
            'service-naming-conventions'
          ]
        }
      ],
      '/migration/': [
        {
          title: 'Migration',
          collapsable: false,
          children: [
            '',
            'consolidation-plan',
            'release-coordination-plan',
            'UNIFIED_ARCHITECTURE'
          ]
        }
      ]
    }
  },
  plugins: [
    ['@vuepress/plugin-search', {
      locales: {
        '/': {
          placeholder: 'Search documentation'
        }
      },
      maxSuggestions: 10
    }]
  ],
  markdown: {
    lineNumbers: true
  }
} 