---
id: ai_coding_assistant-api-reference
---
# API Reference

This document provides a comprehensive reference for the LLM PlatformAI Coding Assistant API.

## Table of Contents

- [AICodingAssistant (llm-mcp)](#aicodingassistant-llm-mcp)
- [CodingAssistant (native_aijs)](#codingassistant-native_aijs)
- [Interfaces](#interfaces)
- [Configuration](#configuration)

## AICodingAssistant (llm-mcp)

The `AICodingAssistant` class from llm-mcp provides MCP-based coding assistance with tool orchestration and git integration.

### Constructor

```typescript
constructor(
  toolRegistry: McpToolRegistry,
  vectorBridge: VectorBridge,
  toolManager: ToolManager,
  intelligenceManager: IntelligenceManager,
  connectionPool: ConnectionPool
)
```

| Parameter | Type | Description |
|-----------|------|-------------|
| `toolRegistry` | `McpToolRegistry` | Registry for MCP tools |
| `vectorBridge` | `VectorBridge` | Bridge for vector operations |
| `toolManager` | `ToolManager` | Manager for tool execution |
| `intelligenceManager` | `IntelligenceManager` | Manager for intelligence operations |
| `connectionPool` | `ConnectionPool` | Pool for connections |

### Methods

#### processCodingTask

```typescript
public async processCodingTask(
  task: CodingTask, 
  codebaseContext: CodebaseContext
): Promise<any>
```

Processes a natural language coding task.

| Parameter | Type | Description |
|-----------|------|-------------|
| `task` | `CodingTask` | The coding task to process |
| `codebaseContext` | `CodebaseContext` | Context about the codebase |

**Returns**: Promise resolving to the result of processing the task

#### executeTaskPlan

```typescript
private async executeTaskPlan(
  plan: TaskPlan, 
  context: CodebaseContext
): Promise<any>
```

Executes a task plan using registered tools.

| Parameter | Type | Description |
|-----------|------|-------------|
| `plan` | `TaskPlan` | The task plan to execute |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to the result of executing the plan

#### handleCodebaseSearch

```typescript
private async handleCodebaseSearch(
  parameters: any, 
  context: CodebaseContext
): Promise<any>
```

Handles codebase search requests.

| Parameter | Type | Description |
|-----------|------|-------------|
| `parameters` | `any` | Search parameters |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to search results

#### handleCodeEdit

```typescript
private async handleCodeEdit(
  parameters: any, 
  context: CodebaseContext
): Promise<any>
```

Handles code edit requests.

| Parameter | Type | Description |
|-----------|------|-------------|
| `parameters` | `any` | Edit parameters |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to edit results

#### handleGitOperations

```typescript
private async handleGitOperations(
  parameters: any, 
  context: CodebaseContext
): Promise<any>
```

Handles git operations.

| Parameter | Type | Description |
|-----------|------|-------------|
| `parameters` | `any` | Git operation parameters |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to git operation results

#### handleTestGeneration

```typescript
private async handleTestGeneration(
  parameters: any, 
  context: CodebaseContext
): Promise<any>
```

Handles test generation requests.

| Parameter | Type | Description |
|-----------|------|-------------|
| `parameters` | `any` | Test generation parameters |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to generated tests

#### handleArchitectureVisualization

```typescript
private async handleArchitectureVisualization(
  parameters: any, 
  context: CodebaseContext
): Promise<any>
```

Handles architecture visualization requests.

| Parameter | Type | Description |
|-----------|------|-------------|
| `parameters` | `any` | Visualization parameters |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to visualization results

#### handleTaskPlanning

```typescript
private async handleTaskPlanning(
  parameters: any, 
  context: CodebaseContext
): Promise<any>
```

Handles task planning requests.

| Parameter | Type | Description |
|-----------|------|-------------|
| `parameters` | `any` | Task planning parameters |
| `context` | `CodebaseContext` | The codebase context |

**Returns**: Promise resolving to task plan

## CodingAssistant (native_aijs)

The `CodingAssistant` class from native_aijs provides neural fabric coding assistance with pattern recognition and neurosymbolic reasoning.

### Constructor

```typescript
constructor(
  neuralFabric: NeuralFabric,
  patternAnalyzer: BasicPatternAnalyzer,
  entityLearner: BasicEntityLearner,
  emergentConsciousness: EmergentConsciousness,
  neuroSymbolicHypergraph: NeuroSymbolicHypergraph,
  llmHypergraphBridge: LLMHypergraphBridge,
  embeddingProvider: EmbeddingProvider,
  config: CodingAssistantConfig
)
```

| Parameter | Type | Description |
|-----------|------|-------------|
| `neuralFabric` | `NeuralFabric` | Neural fabric for content processing |
| `patternAnalyzer` | `BasicPatternAnalyzer` | Analyzer for code patterns |
| `entityLearner` | `BasicEntityLearner` | Learner for code entities |
| `emergentConsciousness` | `EmergentConsciousness` | Emergent consciousness system |
| `neuroSymbolicHypergraph` | `NeuroSymbolicHypergraph` | Neurosymbolic hypergraph |
| `llmHypergraphBridge` | `LLMHypergraphBridge` | Bridge to LLM models |
| `embeddingProvider` | `EmbeddingProvider` | Provider for embeddings |
| `config` | `CodingAssistantConfig` | Configuration for the coding assistant |

### Methods

#### processRequest

```typescript
public async processRequest(
  request: string, 
  context: CodeContext
): Promise<any>
```

Processes a natural language coding request.

| Parameter | Type | Description |
|-----------|------|-------------|
| `request` | `string` | The natural language request |
| `context` | `CodeContext` | The current code context |

**Returns**: Promise resolving to the response to the request

#### analyzeCode

```typescript
public async analyzeCode(
  code: string, 
  options: any = {}
): Promise<CodeAnalysisResult>
```

Analyzes code to understand its structure, patterns, and relationships.

| Parameter | Type | Description |
|-----------|------|-------------|
| `code` | `string` | The code to analyze |
| `options` | `any` | Analysis options |

**Returns**: Promise resolving to analysis results

#### searchCode

```typescript
public async searchCode(
  query: CodeSearchQuery, 
  context: CodeContext
): Promise<CodeSearchResult[]>
```

Searches for code using natural language queries with semantic understanding.

| Parameter | Type | Description |
|-----------|------|-------------|
| `query` | `CodeSearchQuery` | The search query |
| `context` | `CodeContext` | The code context |

**Returns**: Promise resolving to search results

#### suggestCode

```typescript
public async suggestCode(
  context: CodeContext, 
  partial: string
): Promise<CodeSuggestion[]>
```

Generates code suggestions based on context and partial input.

| Parameter | Type | Description |
|-----------|------|-------------|
| `context` | `CodeContext` | The code context |
| `partial` | `string` | Partial code input |

**Returns**: Promise resolving to code suggestions

#### visualizeCode

```typescript
public async visualizeCode(
  config: VisualizationConfig, 
  context: CodeContext
): Promise<VisualizationResult>
```

Generates visualizations of code structure and relationships.

| Parameter | Type | Description |
|-----------|------|-------------|
| `config` | `VisualizationConfig` | Visualization configuration |
| `context` | `CodeContext` | Code context |

**Returns**: Promise resolving to visualization result

#### editCode

```typescript
public async editCode(
  operations: CodeEditOperation[], 
  context: CodeContext
): Promise<any>
```

Edits code with semantic understanding of the changes.

| Parameter | Type | Description |
|-----------|------|-------------|
| `operations` | `CodeEditOperation[]` | Edit operations to perform |
| `context` | `CodeContext` | Code context |

**Returns**: Promise resolving to the result of the edit operation

## Interfaces

### CodingTask

```typescript
interface CodingTask {
  description: string;
  type?: string;
  parameters?: Record<string, any>;
}
```

| Property | Type | Description |
|----------|------|-------------|
| `description` | `string` | Description of the coding task |
| `type` | `string` | Optional type of the coding task |
| `parameters` | `Record<string, any>` | Optional parameters for the coding task |

### CodebaseContext

```typescript
interface CodebaseContext {
  rootDirectory?: string;
  currentDirectory?: string;
  openFiles?: Record<string, string>;
  language?: string;
  stepResults?: Array<{
    tool: string;
    result: any;
  }>;
}
```

| Property | Type | Description |
|----------|------|-------------|
| `rootDirectory` | `string` | Optional root directory of the codebase |
| `currentDirectory` | `string` | Optional current directory |
| `openFiles` | `Record<string, string>` | Optional open files with content |
| `language` | `string` | Optional primary language of the codebase |
| `stepResults` | `Array<{ tool: string; result: any; }>` | Optional results from previous steps |

### TaskPlan

```typescript
interface TaskPlan {
  taskId: string;
  description: string;
  steps: Array<{
    tool: string;
    parameters: Record<string, any>;
  }>;
}
```

| Property | Type | Description |
|----------|------|-------------|
| `taskId` | `string` | ID of the task |
| `description` | `string` | Description of the task |
| `steps` | `Array<{ tool: string; parameters: Record<string, any>; }>` | Steps to execute the task |

### EditOperation

```typescript
interface EditOperation {
  type: 'insert' | 'replace' | 'delete';
  position: {
    start: number;
    end?: number;
  };
  text?: string;
  oldText?: string;
  preserveSemantics?: boolean;
}
```

| Property | Type | Description |
|----------|------|-------------|
| `type` | `'insert' \| 'replace' \| 'delete'` | Type of edit operation |
| `position` | `{ start: number; end?: number; }` | Position in the file |
| `text` | `string` | Optional text to insert or replace with |
| `oldText` | `string` | Optional original text for verification |
| `preserveSemantics` | `boolean` | Optional flag to preserve semantics |

### CodeContext

```typescript
interface CodeContext {
  currentFile: {
    path: string;
    content: string;
    language: string;
  };
  language: string;
  framework?: string;
  projectStructure?: {
    rootDir: string;
    srcDir: string;
    testDir?: string;
    buildConfig?: any;
  };
  codebase?: {
    size: number;
    fileCount: number;
    languages: string[];
    frameworks?: string[];
  };
  preferences?: Record<string, any>;
}
```

| Property | Type | Description |
|----------|------|-------------|
| `currentFile` | `{ path: string; content: string; language: string; }` | The current file being edited |
| `language` | `string` | Programming language |
| `framework` | `string` | Optional framework being used |
| `projectStructure` | `{ rootDir: string; srcDir: string; testDir?: string; buildConfig?: any; }` | Optional project structure information |
| `codebase` | `{ size: number; fileCount: number; languages: string[]; frameworks?: string[]; }` | Optional information about the codebase |
| `preferences` | `Record<string, any>` | Optional user preferences |

## Configuration

### CodingAssistantConfig

```typescript
interface CodingAssistantConfig {
  numberOfSuggestions?: number;
  maxSuggestionLength?: number;
  enableSemanticPreservation?: boolean;
  defaultVisualizationType?: string;
  defaultVisualizationFormat?: string;
  patternLearningRate?: number;
  entityDetectionThreshold?: number;
  enableEmergentConsciousness?: boolean;
  contextWindowSize?: number;
  neuralFabricOptions?: Record<string, any>;
}
```

| Property | Type | Description |
|----------|------|-------------|
| `numberOfSuggestions` | `number` | Optional number of suggestions to generate for code completion |
| `maxSuggestionLength` | `number` | Optional maximum length of suggestions |
| `enableSemanticPreservation` | `boolean` | Optional flag to enable semantic preservation checking |
| `defaultVisualizationType` | `string` | Optional default visualization type |
| `defaultVisualizationFormat` | `string` | Optional default visualization format |
| `patternLearningRate` | `number` | Optional learning rate for pattern recognition |
| `entityDetectionThreshold` | `number` | Optional entity detection threshold |
| `enableEmergentConsciousness` | `boolean` | Optional flag to enable emergent consciousness features |
| `contextWindowSize` | `number` | Optional context window size for code analysis |
| `neuralFabricOptions` | `Record<string, any>` | Optional advanced options for the neural fabric |

### See Also

- [Installation Guide](./installation)
- [Usage Guide](./usage)
- [Examples](./examples)
- [Integration Guide](./integration)
