# Contrib Module Replacement Plan

## Overview
This document outlines how to replace custom modules with existing Drupal contrib modules to reduce maintenance burden and leverage community support.

## Custom Modules to Replace

### 1. drupal_native_ai → drupal/ai + ai_provider_llm-gateway

**Replace with:**
- `drupal/ai` (Core AI framework) 
- `drupal/ai_agents` (Agent capabilities) 
- `drupal/ai_automators` (Field automation) 
- `drupal/ai_ckeditor` (Editor integration) 
- `drupal/ai_assistant_api` (Assistant functionality) 
- `drupal/ai_chatbot` (Chatbot features) 
- `ai_provider_llm-gateway` (Our custom provider for llm-gateway) 

**Migration steps:**
1. Remove AI field widget/formatter - use AI Automators instead
2. Remove provider detection - use AI module's provider system
3. Keep benchmark/comparison features as they're unique
4. Migrate model registry to use AI module's model management

### 2. drupal_migration_plus → migrate_plus + ai_agent_migration + ECA

**Replace with:**
- `drupal/migrate_plus` (already a dependency)
- `drupal/ai_agent_migration` (AI-powered migration)
- `drupal/eca` (Workflow automation)
- `drupal/migrate_tools` (UI for migrations)

**What to keep:**
- Multi-CMS adapters (WordPress, Joomla, Sitecore) - these are unique
- Parallel processing system - this is advanced functionality
- Visual field mapping UI - this is unique

**Migration steps:**
1. Extract CMS adapters as separate contrib modules
2. Use ECA for migration workflows instead of custom orchestration
3. Leverage ai_agent_migration for AI-powered field mapping

### 3. field_eca_bridge → drupal/eca + drupal/ai_automators

**Replace with:**
- `drupal/eca` (Event-Condition-Action)
- `drupal/ai_automators` (AI field processing)
- `drupal/workflow_eca` (Workflow integration)

**Migration steps:**
1. Convert custom ECA conditions to standard ECA plugins
2. Use AI Automators for field processing instead of custom bridge
3. Create ECA models for existing workflows

### 4. ai_swarm_intelligence → drupal/ai_agents + drupal/queue_ui

**Consider:**
- This module has unique distributed AI processing capabilities
- Could be contributed to drupal.org as a new module
- Use `drupal/ai_agents` for basic agent functionality
- Use `drupal/queue_ui` for queue management

**Options:**
1. Contribute as new module to drupal.org
2. Simplify to use AI Agents + custom plugins
3. Extract core swarm logic as library

### 5. alternative_services → drupal/service_container + DDEV

**Replace with:**
- Standard DDEV configuration
- `drupal/service_container` for service management
- Docker Compose for orchestration

**Migration steps:**
1. Move DDEV orchestration to standard DDEV addons
2. Use environment variables for service discovery
3. Remove custom service management code

### 6. api_normalization → drupal/openapi + drupal/schemata

**Replace with:**
- `drupal/openapi` (OpenAPI integration)
- `drupal/openapi_jsonapi` (JSON:API OpenAPI)
- `drupal/schemata` (Schema generation)
- `drupal/api_doc` (API documentation)

**What to keep:**
- Neural API engine features (unique)
- Quantum optimization (unique research)

### 7. blockchain_manager

**Options:**
- This is highly specialized - no direct replacement
- Consider contributing to drupal.org
- Or extract as standalone PHP package

### 8. experience_builder_converter → drupal/experience_builder

**Replace with:**
- Wait for stable `drupal/experience_builder` release
- Use `drupal/layout_builder` in the meantime
- Keep Site Studio conversion logic (unique)

### 9. langchain → DEPRECATED

Already marked for deprecation. Remove and use:
- `drupal/ai` for LLM integration
- Direct API calls for advanced features

### 10. llm → drupal/ai

**Replace with:**
- `drupal/ai` (comprehensive AI framework)
- Move entity types to config entities
- Use AI module's provider system

### 11. secure_drupal → Existing security modules

**Replace with:**
- `drupal/seckit` (Security Kit)
- `drupal/security_review` (Security Review)
- `drupal/password_policy` (Password Policy)
- `drupal/encrypt` (Encryption)
- `drupal/key` (Key Management)
- `drupal/tfa` (Two-factor Authentication)

## Implementation Priority

### Phase 1: Quick Wins (1-2 weeks)
1.  Replace drupal_native_ai with drupal/ai + custom provider
2. Deprecate langchain module
3. Replace secure_drupal with security module suite

### Phase 2: Service Integration (2-3 weeks)
1. Simplify alternative_services to use DDEV
2. Replace api_normalization with OpenAPI modules
3. Migrate field_eca_bridge to standard ECA

### Phase 3: Complex Migrations (3-4 weeks)
1. Refactor drupal_migration_plus to use contrib base
2. Simplify ai_swarm_intelligence to use AI Agents
3. Prepare experience_builder_converter for Experience Builder

### Phase 4: Contribute Back (Ongoing)
1. Package unique features as contrib modules
2. Submit to drupal.org
3. Maintain as community modules

## Benefits

1. **Reduced Maintenance**: Leverage community updates and security fixes
2. **Better Documentation**: Contrib modules have community docs
3. **Wider Testing**: More sites using means more testing
4. **Security Coverage**: Contrib modules get security team coverage
5. **Easier Onboarding**: New developers know contrib modules

## Next Steps

1. Create deprecation notices in custom modules
2. Update composer.json to require contrib modules
3. Create migration scripts for data/config
4. Update documentation
5. Test thoroughly in development
6. Plan phased rollout