# Observability & Monitoring — BFCIComponents

## Recommended Stack
- **OpenTelemetry**: Distributed tracing, metrics, and logs
- **Prometheus**: Metrics collection
- **Grafana**: Visualization and dashboards
- **Loki** (optional): Log aggregation
- **Jaeger** (optional): Trace visualization

## Node.js/TypeScript Quickstart

1. **Install OpenTelemetry SDKs**
```bash
npm install @opentelemetry/api @opentelemetry/sdk-node @opentelemetry/auto-instrumentations-node @opentelemetry/exporter-prometheus
```

2. **Instrument Your App**
```typescript
// tracing.js
const [NodeSDK] = require('@opentelemetry/sdk-node');
const [getNodeAutoInstrumentations] = require('@opentelemetry/auto-instrumentations-node');
const [PrometheusExporter] = require('@opentelemetry/exporter-prometheus');

const sdk = new NodeSDK({
  traceExporter: new PrometheusExporter({ startServer: true }),
  instrumentations: [getNodeAutoInstrumentations()],
});

sdk.start();
```

3. **Start the Tracing SDK Before Your App**
```bash
node -r ./tracing.js src/app.js
```

4. **View Metrics in Prometheus**
- Configure Prometheus to scrape `/metrics` endpoint (default: `localhost:9464/metrics`).
- Add Grafana dashboards for visualization.

## Best Practices
- **Instrument all HTTP, DB, and custom business logic.**
- **Propagate trace context across services.**
- **Use semantic conventions for naming spans and metrics.**
- **Export logs to Loki or another aggregator for unified search.**
- **Monitor error rates, latency, and throughput in Grafana.**

## References
- [OpenTelemetry Node.js](https://opentelemetry.io/docs/instrumentation/js/)
- [Prometheus](https://prometheus.io/docs/introduction/overview/)
- [Grafana](https://grafana.com/docs/grafana/latest/)
- [Loki](https://grafana.com/oss/loki/)
- [Jaeger](https://www.jaegertracing.io/docs/)

---
*For advanced observability or custom dashboards, contact the platform SRE team.* 