# Bluefly CI / CD Components

This document describes the standardized CI / CD components used across Bluefly projects.

## Base Components

### Base Template (`base.yml`)

The base template provides common configuration that all projects inherit:

- Standard stages (validate, test, build, publish, deploy, sync - docs)
- Common cache configuration
- Standard rules for pipeline execution
- Retry policies for job failures
- Artifact management

### Semantic Release (`semantic - release.yml`)

Handles automated versioning and release management:

- Follows semantic versioning
- Generates changelogs
- Creates GitLab releases
- Publishes to registries

### Documentation Components

- `docs - build.yml`: Builds documentation using MkDocs
- `docs - sync.yml`: Syncs documentation to central docs site
- `docs - ci.yml`: Validates documentation formatting and links

## Language - Specific Components

### Node.js (`nodejs.yml`)

Specialized configuration for Node.js projects:

- Node.js - specific cache configuration
- NPM dependency management
- Standard scripts (lint, test, build)
- Integration test support
- Database migration handling

### Python (`python.yml`)

Specialized configuration for Python projects:

- Python virtual environment setup
- PIP dependency management
- Code quality tools (black, flake8, mypy)
- pytest configuration
- Build and deployment scripts

## Usage

To use these components in your project's `.gitlab - ci.yml`:

```yaml
include:

# For Node.js projects

  - component: 'gitlab://bluefly / internal - projects / llm / bfcicomponents / templates / nodejs.yml'

# For Python projects

  - component: 'gitlab://bluefly / internal - projects / llm / bfcicomponents / templates / python.yml'

# Common components

  - component: 'gitlab://bluefly / internal - projects / llm / bfcicomponents / templates / semantic - release.yml'
  - component: 'gitlab://bluefly / internal - projects / llm / bfcicomponents / templates / docs - sync.yml'
```text

Then extend the appropriate templates in your jobs:

```yaml
validate:
  extends: .nodejs_validate # or .python_validate

test:
  extends: .nodejs_test # or .python_test

build:
  extends: .nodejs_build # or .python_build

deploy:
  extends: .nodejs_deploy # or .python_deploy
```text

## Best Practices
1. Always use the latest version of components
2. Don't override template configurations without good reason
3. Keep project - specific configurations minimal
4. Document any deviations from standard templates
5. Contribute improvements back to shared components

## Contributing
To contribute improvements to these components:

1. Create a merge request in the BFCIComponents repository
2. Include tests for new functionality
3. Update documentation
4. Follow the semantic commit message format
5. Request review from the DevOps team
