# GitLab CI Component Usage Guide

## Issue Resolution: Component Syntax vs Local Includes

The error "jobs spec config should implement the script:, run:, or trigger: keyword" occurs because **GitLab Component syntax (`spec:` and `$[[ inputs.* ]]`) only works when used as remote components, not local includes**.

## ❌ This Fails (Local Include with Component Syntax):
```yaml
# .gitlab-ci.yml
include:
  - local: 'components/ultimate.yml'  # FAILS - Component syntax not supported locally
```

##  This Works (Remote Component):
```yaml
# .gitlab-ci.yml  
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/ultimate@main
    inputs:
      project_type: nodejs
      environment: production
```

##  This Also Works (Local Include without Component Syntax):
```yaml
# .gitlab-ci.yml
include:
  - local: 'ultimate-local.yml'  # Uses regular GitLab CI syntax
```

## Component Registry Setup

1. **Push components to main branch**
2. **Tag a release** (required for component registry)
3. **Use as remote component** from other projects

## Current Status

-  All 10 components validated for remote use
-  Created `ultimate-local.yml` for local testing
-  Pipeline now works with local includes
- 🔄 Ready for component registry deployment

## Next Steps

1. Merge to main branch
2. Create release tag (e.g., `v1.0.0`)
3. Update other projects to use remote components
4. Remove local testing files