# Authentication Component

A GitLab CI/CD component for managing user authentication and API security.

## Features

- JWT-based authentication
- API key management
- Session handling
- Security best practices
- Test automation

## Inputs

| Input           | Required | Default     | Description                            |
| --------------- | -------- | ----------- | -------------------------------------- |
| jwt_secret      | Yes      | -           | Secret key for JWT signing             |
| jwt_expires_in  | No       | "24h"       | JWT token expiration time              |
| auth_timeout    | No       | 5000        | Authentication timeout in milliseconds |
| api_key_header  | No       | "X-API-Key" | Header name for API key                |
| session_timeout | No       | 3600        | Session timeout in seconds             |

## Usage

```yaml
include:
  - component: gitlab.com/your-namespace/bfci-components/authentication@1.0.0
    inputs:
      jwt_secret: $JWT_SECRET
      jwt_expires_in: '24h'
```

## Testing

The component includes automated tests that verify:

1. JWT token generation and validation
2. API key authentication
3. Session management
4. Error handling
5. Security measures


To run tests locally:

```bash
./test.sh
```

## Artifacts

The component generates the following artifacts:

- Test reports in JUnit format
- Coverage reports
- Security audit logs
- Error logs

## Security

- JWT secrets should be stored in CI/CD variables
- All tokens are encrypted
- Regular security audits are performed
- Access control is enforced
- Rate limiting is implemented

## Contributing

1. Fork the repository
2. Create a feature branch
3. Submit a merge request


## License

MIT License - See LICENSE.md for details
