# Jest Config Component

Jest configuration utilities to ensure consistent test setup across all projects.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/jest-config@main
    inputs:
      config_profile: "typescript" # options: "standard", "typescript", "simple"
      coverage_threshold: 80
      coverage_reporting: true
```

## Features

This component provides:

- Ready-to-use Jest configurations for different project types
- Multiple configuration profiles (standard, TypeScript, simple)
- Customizable coverage thresholds
- Automatic test execution and reporting
- Configurable test paths and setup files

## Configuration Profiles

- **standard**: Base configuration for JavaScript projects
- **typescript**: Enhanced configuration with TypeScript support
- **simple**: Minimal configuration for quick tests with less overhead

## Scripts

This component provides the following CI/CD scripts:

- `jest-config-job`: Sets up the appropriate Jest configuration
- `jest-test-job`: Runs tests and generates coverage reports
- `jest-report-job`: Publishes coverage reports (optional)

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `project_type` | Type of project | string | `nodejs` | ❌ |
| `config_profile` | Jest configuration profile | string | `standard` | ❌ |
| `coverage_threshold` | Test coverage threshold percentage | number | `80` | ❌ |
| `coverage_reporting` | Generate and publish coverage reports | boolean | `true` | ❌ |
| `test_path` | Path to test files | string | `tests/` | ❌ |
| `setup_file` | Path to Jest setup file | string | `jest.setup.js` | ❌ |

## Configuration Files

The component includes these configuration files:

- `config/jest.config.js`: Standard configuration
- `config/jest.config.typescript.cjs`: TypeScript-optimized configuration
- `config/jest.config.simple.cjs`: Simplified configuration for quick testing

## Examples

### Basic Usage (JavaScript Project)

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/jest-config@main
    inputs:
      config_profile: "standard"
```

### TypeScript Project with Higher Coverage Requirements

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/jest-config@main
    inputs:
      config_profile: "typescript"
      coverage_threshold: 90
      test_path: "src/__tests__/"
```

### Simple Configuration for Quick Testing

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/ci/jest-config@main
    inputs:
      config_profile: "simple"
      coverage_reporting: false
```

## License

MIT License - see LICENSE.md for details