# Code Quality Component Examples

This directory contains examples demonstrating how to use the code-quality component in real-world projects.

## Example GitLab CI Configuration

The `example-gitlab-ci.yml` file demonstrates a complete GitLab CI/CD pipeline that integrates the code-quality component. It includes:

- Multiple job stages (lint, test, build, quality, deploy)
- Code quality checks with various tools enabled
- Quality dashboard generation and publishing
- Scheduled quality trend analysis

## Example Project

The `project/` directory contains a sample project structure that demonstrates code quality practices:

### Project Structure

```
project/
├── .eslintrc.js              # ESLint configuration
├── .markdownlint.json        # Markdownlint configuration
├── .stylelintrc.json         # Stylelint configuration
├── package.json              # Project dependencies and scripts
├── phpcs.xml                 # PHP_CodeSniffer configuration
├── src/
│   ├── js/                   # TypeScript/JavaScript source
│   │   └── app.ts            # Example TypeScript file with TODOs
│   ├── php/                  # PHP source
│   │   └── Service.php       # Example PHP file with TODOs
│   └── styles/               # SCSS styles
│       └── main.scss         # Example SCSS file with TODOs
└── docs/
    └── README.md             # Example documentation with TODOs
```

### Todo Examples

The sample files contain various TODOs with different priorities and categories:

```typescript
// Simple TODO
// TODO: Implement feature X

// TODO with priority
// TODO(high): Fix critical bug

// TODO with category
// TODO(security): Address XSS vulnerability

// TODO with both
// TODO(critical): Fix data loss issue
```

### Running the Code Quality Checks

To run code quality checks on the example project:

1. Install the project dependencies:
   ```bash
   cd project
   npm install
   ```

2. Run TODO analysis:
   ```bash
   npm run todo
   ```

3. Run the quality dashboard:
   ```bash
   npm run quality:dashboard
   ```

## Using These Examples

You can use these examples as a reference for:

1. Setting up your GitLab CI/CD pipeline with code quality checks
2. Configuring code quality tools for your project
3. Implementing a TODO management strategy
4. Generating quality dashboards and reports

## Best Practices

These examples demonstrate several best practices:

1. **Consistent Configuration**: Use consistent configuration across tools
2. **Quality Automation**: Automate quality checks in CI/CD
3. **Categorized TODOs**: Use priorities and categories for TODOs
4. **Clear Documentation**: Document quality standards and practices
5. **Dashboard Integration**: Generate visual quality dashboards