# Docker Service CI Component

This component provides a comprehensive CI/CD pipeline for Docker-based services with multi-stage builds, security scanning, and deployment options.

## Features

- Multi-architecture builds (amd64, arm64)
- Container security scanning (Trivy or Grype)
- Automated staging deployment
- Manual production deployment
- Health checks
- Slack notifications
- llmcli integration

## Usage

Include this component in your GitLab CI configuration:

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/docker-service@main
    inputs:
      service_name: "api-gateway"
      docker_image_base: "node:20-alpine"
      enable_multi_arch: true
      enable_security_scan: true
      enable_staging_deploy: true
      enable_production_deploy: true
```

## Configuration

### Basic Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `service_name` | Service name (used for container naming) | "my-service" |
| `docker_image_base` | Base Docker image | "node:20-alpine" |
| `dockerfile_path` | Path to Dockerfile | "Dockerfile" |
| `build_context` | Docker build context path | "." |

### Registry Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `registry_url` | Docker registry URL | "registry.example.com" |
| `image_name` | Docker image name | "registry.example.com/project" |

### Build Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `enable_multi_arch` | Enable multi-architecture builds | true |
| `build_args` | Docker build arguments (KEY=value format) | "" |

### Security Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `enable_security_scan` | Enable container security scanning | true |
| `security_scanner` | Security scanner to use (trivy, grype) | "trivy" |

### Deployment Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `enable_staging_deploy` | Enable automatic staging deployment | true |
| `enable_production_deploy` | Enable manual production deployment | true |
| `staging_namespace` | Kubernetes namespace for staging | "staging" |
| `production_namespace` | Kubernetes namespace for production | "production" |

### Health Check Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `health_check_url` | Health check endpoint | "/health" |
| `health_check_timeout` | Health check timeout in seconds | 30 |

### llmcli Integration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `enable_llmcli` | Use llmcli for additional CI operations | true |
| `llmcli_package` | llmcli package name | "@bluefly/cli" |

### Notification Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `slack_webhook_var` | GitLab CI variable name containing Slack webhook URL | "SLACK_WEBHOOK_URL" |

## Example: Minimal Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/docker-service@main
    inputs:
      service_name: "auth-service"
      dockerfile_path: "Dockerfile.prod"
```

## Example: Full Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/docker-service@main
    inputs:
      # Service Configuration
      service_name: "api-gateway"
      
      # Docker Configuration
      docker_image_base: "node:20-alpine"
      dockerfile_path: "Dockerfile.production"
      build_context: "."
      registry_url: "registry.example.com"
      image_name: "registry.example.com/project"
      
      # Build Configuration
      enable_multi_arch: true
      build_args: |
        NODE_ENV=production
        VERSION=[CI_COMMIT_SHA]
      
      # Security Configuration
      enable_security_scan: true
      security_scanner: "trivy"
      
      # Deployment Configuration
      enable_staging_deploy: true
      enable_production_deploy: true
      staging_namespace: "staging"
      production_namespace: "production"
      
      # Health Check Configuration
      health_check_url: "/health"
      health_check_timeout: 60
      
      # llmcli Integration
      enable_llmcli: true
      llmcli_package: "@bluefly/cli"
      
      # Notification Configuration
      slack_webhook_var: "SLACK_WEBHOOK_URL"
```

## License

MIT