# Drupal Scheduled Tests Component

GitLab CI/CD component for running scheduled tests and health monitoring.

## Features

- Scheduled comprehensive test suites
- Health monitoring and uptime checks
- Performance regression testing
- Security vulnerability scanning
- Accessibility compliance testing
- Visual regression testing

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-scheduled-tests@main

nightly_tests:
  extends: .drupal_scheduled_tests
  variables:
    schedule: "0 3 * * *"
    test_suites: "health,performance,security"
    environment: "production"
  rules:
    - if: $CI_PIPELINE_SOURCE == "schedule"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `schedule` | string | "0 3 * * *" | Test schedule expression |
| `test_suites` | string | "health" | Comma-separated test suites to run |
| `environment` | string | "production" | Target environment |
| `alert_threshold` | string | "80" | Alert threshold percentage |
| `enable_notifications` | string | "true" | Enable failure notifications |
| `performance_budget` | string | "3000" | Performance budget in ms |

## Available Test Suites

- `health` - Basic health and uptime checks
- `performance` - Performance regression testing
- `security` - Security vulnerability scans
- `accessibility` - WCAG compliance testing
- `visual` - Visual regression testing
- `integration` - End-to-end integration tests

## Requirements

- Drupal site accessible for testing
- Testing tools configured
- Monitoring endpoints available
- Notification webhooks configured