# Drupal Kernel Testing Component

GitLab CI/CD component for running Drupal kernel tests with database integration.

## Features

- PHPUnit kernel testing with full Drupal bootstrap
- Database setup and management (MySQL, PostgreSQL, SQLite)
- Module installation and configuration testing
- Performance profiling for kernel tests
- Memory optimization for complex bootstrap scenarios
- Parallel execution support for faster testing

## Usage

```yaml
include:
  - component: gitlab.bluefly..io/bluefly/bfcicomponents/drupal-test-kernel@main

kernel_tests:
  extends: .drupal_kernel_tests
  variables:
    php_version: "8.3"
    database_type: "mysql"
    enable_profiling: "true"
```

## Inputs

| Input | Type | Default | Description |
|-------|------|---------|-------------|
| `php_version` | string | "8.3" | PHP version to use (8.1, 8.2, 8.3, 8.4) |
| `database_type` | string | "mysql" | Database type (mysql, postgresql, sqlite) |
| `database_version` | string | "8.0" | Database version |
| `enable_profiling` | string | "false" | Enable performance profiling |
| `memory_limit` | string | "512M" | PHP memory limit for kernel tests |
| `test_suite` | string | "kernel" | PHPUnit test suite to run |
| `parallel_jobs` | string | "2" | Number of parallel test processes |

## Output Artifacts

- Kernel test results (JUnit XML)
- Performance profiles and metrics
- Database schema dumps
- Bootstrap timing reports

## Requirements

- Drupal 9.5+ or Drupal 10+
- Database service (MySQL 8.0+, PostgreSQL 13+, or SQLite)
- PHPUnit with Drupal kernel test base classes