# K8s Base Component

This component provides base Kubernetes resources that can be used by all services, including namespace definitions and shared configuration.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/base@main
    inputs:
      environment: production
      namespace: bluefly-ai
      version: 1.0.0
```

## Features

This component provides:

- Common Kubernetes resource definitions that can be shared across services
- Environment-specific configuration via ConfigMaps
- Namespace management
- Parameterized configuration for all platform services
- Consistent environment variables and settings

## Manifests

The component includes these Kubernetes manifests:

- `manifests/namespace.yaml`: Namespace definition with appropriate labels
- `manifests/configmap.yaml`: ConfigMap with environment-specific configuration

## Scripts

This component provides the following CI/CD scripts:

- `k8s-base-prepare`: Prepares the manifests with the provided parameters
- `k8s-base-deploy`: Deploys the base resources to the Kubernetes cluster
- `k8s-base-verify`: Verifies that the resources are correctly deployed

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `environment` | Target environment | string | `development` | ❌ |
| `namespace` | Kubernetes namespace | string | `bluefly-ai` | ❌ |
| `version` | Platform version | string | `1.0.0` | ❌ |
| `node_env` | NODE_ENV value | string | `development` | ❌ |
| `log_level` | Logging level | string | `info` | ❌ |
| `postgres_db` | PostgreSQL database name | string | `bluefly_ai` | ❌ |
| `postgres_user` | PostgreSQL username | string | `bluefly` | ❌ |
| `redis_host` | Redis host | string | `bluefly-redis` | ❌ |
| `redis_port` | Redis port | string | `6379` | ❌ |

## Examples

### Production Environment Setup

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/base@main
    inputs:
      environment: production
      version: 1.2.3
      node_env: production
      log_level: info
```

### Development Environment with Custom Database

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/base@main
    inputs:
      environment: development
      namespace: bluefly-ai-dev
      postgres_db: bluefly_ai_dev
      log_level: debug
```

### Staging Environment

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/base@main
    inputs:
      environment: staging
      namespace: bluefly-ai-staging
      version: 0.9.0-beta
```

## License

MIT License - see LICENSE.md for details