# llm-gateway K8s Component

This component provides Kubernetes resources for deploying and managing the llm-gateway (API Gateway) service.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/llm-gateway@main
    inputs:
      environment: production
      namespace: bluefly-ai
      replicas: 2
      image_tag: v1.2.3
      cpu_request: 500m
      memory_request: 512Mi
```

## Features

This component provides:

- Parameterized Kubernetes manifests for llm-gateway deployments
- Configurable resource requirements
- Automatic environment-specific configurations
- Deployment verification and health checks
- Service configuration with customizable port and service type

## Manifests

The component includes these Kubernetes manifests:

- `manifests/deployment.yaml`: Deployment configuration with parameterized values
- `manifests/service.yaml`: Service configuration with customizable settings

## Scripts

This component provides the following CI/CD scripts:

- `llm-gateway-prepare-manifests`: Prepares the manifests with the provided parameters
- `llm-gateway-deploy`: Deploys the manifests to the Kubernetes cluster
- `llm-gateway-verify`: Verifies that the deployment is successful and healthy

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `environment` | Target environment for deployment | string | `development` | ❌ |
| `namespace` | Kubernetes namespace | string | `bluefly-ai` | ❌ |
| `replicas` | Number of replicas to deploy | number | `1` | ❌ |
| `image_tag` | Docker image tag to deploy | string | `latest` | ❌ |
| `cpu_request` | CPU request for each pod | string | `500m` | ❌ |
| `memory_request` | Memory request for each pod | string | `512Mi` | ❌ |
| `cpu_limit` | CPU limit for each pod | string | `2000m` | ❌ |
| `memory_limit` | Memory limit for each pod | string | `2Gi` | ❌ |
| `service_type` | Kubernetes service type | string | `ClusterIP` | ❌ |
| `service_port` | Service port | number | `80` | ❌ |

## Examples

### Basic Production Deployment

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/llm-gateway@main
    inputs:
      environment: production
      replicas: 3
      image_tag: v1.2.3
```

### Development Environment with Minimal Resources

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/llm-gateway@main
    inputs:
      environment: development
      replicas: 1
      image_tag: develop
      cpu_request: 200m
      memory_request: 256Mi
      cpu_limit: 1000m
      memory_limit: 1Gi
```

### Staging Environment with LoadBalancer Service

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/k8s/llm-gateway@main
    inputs:
      environment: staging
      namespace: bluefly-ai-staging
      replicas: 2
      image_tag: staging
      service_type: LoadBalancer
      service_port: 8080
```

## License

MIT License - see LICENSE.md for details