# LLM Platform Integration Component

This component provides integration services for LLM Platform Recipe, enabling comprehensive integration between llmcli and the Drupal LLM Platform Recipe.

## Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llm/platform-integration@main
    inputs:
      environment: production
      ai_providers:
        - openai
        - anthropic
```

## Features

This component provides:

- Recipe validation and deployment
- AI module testing automation
- Multi-provider AI validation
- Performance monitoring
- Security compliance automation
- Provider failover testing

## Services

The component includes these services:

- `LLMPlatformIntegrationService.js`: Core service for LLM Platform integration

## Scripts

This component provides the following CI/CD jobs:

- `llm-platform-validate`: Validates the LLM Platform Recipe
- `llm-platform-deployment-plan`: Generates a deployment plan for the recipe
- `llm-module-tests`: Generates tests for AI modules
- `llm-platform-monitor`: Sets up performance monitoring for the platform

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `environment` | Target environment | string | `development` | ❌ |
| `recipe_path` | Path to the LLM Platform Recipe | string | `_DrupalModules/llm_platform_recipe` | ❌ |
| `ai_providers` | List of AI providers to use | array | `['openai']` | ❌ |
| `response_time_threshold` | Response time threshold in ms | number | `3000` | ❌ |
| `error_rate_threshold` | Error rate threshold (0-1) | number | `0.05` | ❌ |
| `enable_performance_monitoring` | Enable performance monitoring | boolean | `true` | ❌ |
| `enable_security_compliance` | Enable security compliance checks | boolean | `true` | ❌ |

## Examples

### Basic Usage

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llm/platform-integration@main
    inputs:
      environment: development
```

### Production Configuration with Multiple AI Providers

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llm/platform-integration@main
    inputs:
      environment: production
      ai_providers:
        - openai
        - anthropic
        - azure-openai
      response_time_threshold: 2000
      error_rate_threshold: 0.02
```

### Custom Recipe Path with Minimal Monitoring

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/llm/platform-integration@main
    inputs:
      environment: staging
      recipe_path: custom/llm_platform
      enable_performance_monitoring: false
      ai_providers:
        - vertexai
```

## License

MIT License - see LICENSE.md for details