# Model Management Component

A GitLab CI/CD component for managing ML models, versions, and artifacts.

## Features

- Model creation and management
- Version control
- Artifact handling
- Performance monitoring
- Test automation

## Inputs

| Input                 | Required | Default | Description                                  |
| --------------------- | -------- | ------- | -------------------------------------------- |
| model_api_url         | Yes      | -       | URL of the model API                         |
| model_api_timeout     | No       | 30000   | API request timeout in milliseconds          |
| model_api_retry_count | No       | 3       | Number of retry attempts for failed requests |
| model_api_retry_delay | No       | 1000    | Delay between retries in milliseconds        |
| model_api_key         | Yes      | -       | API key for authentication                   |

## Usage

```yaml
include:
  - component: gitlab.com/your-namespace/bfci-components/model-management@1.0.0
    inputs:
      model_api_url: 'http://your-api-url'
      model_api_key: $MODEL_API_KEY
```

## Testing

The component includes automated tests that verify:

1. Model creation and retrieval
2. Version management
3. Artifact handling
4. Error handling
5. Performance metrics


To run tests locally:

```bash
./test.sh
```

## Artifacts

The component generates the following artifacts:

- Test reports in JUnit format
- Coverage reports
- Performance metrics
- Error logs

## Security

- API keys should be stored in CI/CD variables
- All API requests are encrypted
- Access control is enforced
- Regular security audits are performed

## Contributing

1. Fork the repository
2. Create a feature branch
3. Submit a merge request


## License

MIT License - See LICENSE.md for details
