# Node.js Build Component

A GitLab CI/CD component for building, testing, and analyzing Node.js applications.

## Features

- Automated Node.js build pipeline
- Dependency installation with npm or yarn
- Test execution with coverage reporting
- Dependency caching for faster builds
- Configurable Node.js version
- Support for custom Docker images

## Usage

Include this component in your `.gitlab-ci.yml`:

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bfci-components/nodejs-build@1.0.0
    inputs:
      enabled: true
      node_version: '18'
      install_command: 'npm ci'
      build_command: 'npm run build'
      test_command: 'npm test'
      coverage_enabled: true
      cache_enabled: true
```

## Inputs

| Input             | Type    | Default                                                                                          | Description                         |
| ----------------- | ------- | ------------------------------------------------------------------------------------------------ | ----------------------------------- |
| enabled           | boolean | true                                                                                             | Enable Node.js build processing     |
| node_version      | string  | "18"                                                                                             | Node.js version to use              |
| install_command   | string  | "npm ci"                                                                                         | Command to install dependencies     |
| build_command     | string  | "npm run build"                                                                                  | Command to build the application    |
| test_command      | string  | "npm test"                                                                                       | Command to run tests                |
| coverage_enabled  | boolean | true                                                                                             | Enable code coverage reporting      |
| cache_enabled     | boolean | true                                                                                             | Enable dependency caching           |
| use_custom_image  | boolean | true                                                                                             | Use the Bluefly custom Docker image |
| custom_image_path | string  | "registry.gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bluefly-docker-image:latest" | Path to the custom Docker image     |

## Requirements

- GitLab CI/CD
- Node.js environment
- package.json with defined scripts
- (Optional) Jest or other test framework for coverage reporting

## License

This component is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.
