# Node.js NPM Publishing Component

Enterprise-grade npm package publishing with semantic versioning and registry integration

## Usage

```yaml
include:
  - component: $CI_SERVER_FQDN/$CI_PROJECT_PATH/nodejs-npm@main
    inputs:
      node_version: "20"
      release_branch: "main"
      npm_token: "$NPM_TOKEN"
```

## Inputs

| Input | Description | Type | Default | Required |
|-------|-------------|------|---------|----------|
| `node_version` | Node.js version to use | string | `20` | ❌ |
| `npm_token` | NPM registry token | string | |  |
| `release_branch` | Branch to release from | string | `main` | ❌ |
| `package_manager` | Package manager to use | string | `npm` | ❌ |
| `enable_security_scan` | Run security scanning | boolean | `true` | ❌ |
| `enable_build_cache` | Enable build caching | boolean | `true` | ❌ |
| `public_package` | Is package public on npm | boolean | `true` | ❌ |
| `node_options` | Node.js options | string | `--max-old-space-size=4096` | ❌ |

## Features

- Automated semantic versioning based on commits
- NPM publishing with token authentication
- Comprehensive test suite execution
- TypeScript type declaration verification
- Security vulnerability scanning
- Bundle size analysis and optimization

## Requirements

- GitLab 17.0+ for component support
- Properly structured Node.js package with package.json
- Jest tests for test coverage
- NPM account with token

## License

MIT License - see LICENSE.md for details