# NPM Golden CI Package Component

This component provides a golden path CI/CD pipeline for Node.js npm packages, incorporating best practices for quality, security, and automated publishing to npm.org.

## Usage

```yaml
include:
  - component: $CI_SERVER_FQDN/$CI_PROJECT_PATH/nodejs/npm_golden_ci_package@main
    inputs:
      node_version: "20"
      npm_token: "$NPM_TOKEN"
      release_branch: "main"
      package_manager: "npm"
      public_package: true
```

## Purpose

This component is intended for repositories that contain a Node.js package intended for npm publishing. It focuses on:

- **Automated Linting**: Enforces code quality and style.
- **Comprehensive Testing**: Runs all tests and enforces coverage thresholds.
- **Security Scanning**: Checks for vulnerabilities in dependencies.
- **Type Checking**: Ensures TypeScript type safety (if applicable).
- **Bundle Analysis**: Reports bundle size and optimizations.
- **Semantic Release**: Automated versioning and changelog generation.
- **NPM Publishing**: Publishes to npm.org with token authentication.

## Inputs

| Input                | Description                                 | Type    | Default   |
|----------------------|---------------------------------------------|---------|-----------|
| `node_version`       | Node.js version to use                      | string  | "20"      |
| `npm_token`          | NPM registry token                          | string  |           |
| `release_branch`     | Branch to release from                      | string  | "main"    |
| `package_manager`    | Package manager (npm, yarn, pnpm)           | string  | "npm"     |
| `public_package`     | Is package public on npm                    | boolean | true      |
| `enable_security_scan` | Run security scanning                     | boolean | true      |
| `enable_build_cache` | Enable build caching                        | boolean | true      |
| `min_test_coverage`  | Minimum required test coverage (%)          | number  | 80        |

## Features

- Streamlined CI for npm package development and publishing
- Automated lint, test, coverage, and security checks
- Semantic versioning and changelog management
- Automated publishing to npm.org
- Bundle size and type declaration checks

## Requirements

- GitLab 17.0+ for component support
- Properly structured Node.js package with package.json
- Jest or similar test suite for coverage
- NPM account with token

## License

MIT License - see LICENSE.md for details 