# NPM Package CI Component

This component provides a comprehensive CI/CD pipeline for NPM packages with testing, linting, versioning, and publishing.

## Features

- Automated testing and linting
- Semantic versioning
- NPM package publishing
- Documentation generation
- Coverage reporting
- Dependency auditing

## Usage

Include this component in your GitLab CI configuration:

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/npm-package@main
    inputs:
      package_name: "my-package"
      node_version: "20"
      test_command: "npm test"
```

## Configuration

### Basic Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `package_name` | NPM package name | From package.json |
| `node_version` | Node.js version to use | "20" |
| `package_manager` | Package manager to use | "npm" |
| `package_directory` | Directory containing package.json | "." |
| `main_branch` | Main branch name | "main" |

### Build Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `build_command` | Command to build the package | "npm run build" |
| `skip_build` | Skip build step | false |
| `enable_typescript` | Enable TypeScript build | true |
| `typescript_version` | TypeScript version | "5" |
| `typescript_strict` | Enable TypeScript strict mode | true |

### Test Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `test_command` | Command to run tests | "npm test" |
| `skip_tests` | Skip test step | false |
| `coverage_threshold` | Coverage threshold percentage | 80 |
| `report_coverage` | Report coverage to GitLab | true |
| `jest_config_path` | Path to Jest config | "jest.config.js" |

### Lint Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `lint_command` | Command to run linting | "npm run lint" |
| `skip_lint` | Skip lint step | false |
| `eslint_config_path` | Path to ESLint config | ".eslintrc.js" |
| `prettier_config_path` | Path to Prettier config | ".prettierrc" |

### Publish Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `publish_enabled` | Enable package publishing | true |
| `scope` | NPM package scope | "" |
| `access` | NPM package access (public/restricted) | "public" |
| `registry` | NPM registry URL | "https://registry.npmjs.org/" |
| `token_variable` | CI variable for NPM token | "NPM_TOKEN" |
| `run_audit` | Run npm audit during CI | true |
| `dry_run` | Perform publish dry-run only | false |

### Documentation Configuration

| Parameter | Description | Default |
|-----------|-------------|---------|
| `docs_command` | Command to generate docs | "npm run docs" |
| `skip_docs` | Skip documentation generation | false |
| `docs_output_dir` | Documentation output directory | "docs" |
| `deploy_docs` | Deploy documentation to GitLab Pages | true |

## Example: Minimal Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/npm-package@main
    inputs:
      package_name: "my-util-library"
      node_version: "18"
```

## Example: Full Configuration

```yaml
include:
  - component: gitlab.bluefly.io/llm/bfcicomponents/components/npm-package@main
    inputs:
      # Basic Configuration
      package_name: "@bluefly/shared"
      node_version: "20"
      package_manager: "npm"
      package_directory: "."
      main_branch: "main"
      
      # Build Configuration
      build_command: "npm run build:prod"
      skip_build: false
      enable_typescript: true
      typescript_version: "5"
      typescript_strict: true
      
      # Test Configuration
      test_command: "npm run test:ci"
      skip_tests: false
      coverage_threshold: 90
      report_coverage: true
      jest_config_path: "jest.config.ts"
      
      # Lint Configuration
      lint_command: "npm run lint:ci"
      skip_lint: false
      eslint_config_path: ".eslintrc.js"
      prettier_config_path: ".prettierrc"
      
      # Publish Configuration
      publish_enabled: true
      scope: "@bluefly"
      access: "public"
      registry: "https://registry.npmjs.org/"
      token_variable: "NPM_TOKEN"
      run_audit: true
      dry_run: false
      
      # Documentation Configuration
      docs_command: "npm run docs:build"
      skip_docs: false
      docs_output_dir: "docs/generated"
      deploy_docs: true
```

## License

MIT