# Terraform Deploy Component

A GitLab CI/CD component for automated infrastructure deployment using Terraform.

## Features

- Automated Terraform infrastructure deployment pipeline
- Support for multiple Terraform versions
- Workspace management
- State backend configuration
- Plan and apply stages
- Variable file support
- Custom Docker image support
- Secure credential handling

## Usage

Include this component in your `.gitlab-ci.yml`:

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/core-assets/bfci-components/terraform-deploy@1.0.0
    inputs:
      enabled: true
      terraform_version: '1.7.0'
      workspace: 'production'
      var_file: 'environments/prod.tfvars'
      auto_approve: false
      plan_only: false
```

## Inputs

| Input             | Type    | Default                          | Description                                 |
| ----------------- | ------- | -------------------------------- | ------------------------------------------- |
| enabled           | boolean | true                             | Enable Terraform deployment processing      |
| terraform_version | string  | "1.7.0"                          | Terraform version to use                    |
| workspace         | string  | "default"                        | Terraform workspace to use                  |
| backend_config    | object  | {type: "http"}                   | Backend configuration for state storage     |
| var_file          | string  | "terraform.tfvars"               | Path to terraform.tfvars file               |
| auto_approve      | boolean | false                            | Auto approve terraform apply                |
| plan_only         | boolean | false                            | Only run terraform plan without apply       |
| use_custom_image  | boolean | true                             | Use the Bluefly custom Docker image         |
| custom_image_path | string  | "registry.gitlab.bluefly.io/..." | Path to the custom Docker image             |
| additional_args   | string  | ""                               | Additional arguments for terraform commands |

## Requirements

- GitLab CI/CD
- Terraform configuration files
- Backend configuration for state management
- Required provider credentials (AWS, Azure, etc.)
- Variable files for environment-specific values

## Security Considerations

1. Never commit sensitive credentials to version control
2. Use GitLab CI/CD variables for sensitive values
3. Implement proper IAM roles and permissions
4. Review terraform plan output before applying
5. Use workspaces to isolate environments


## Examples

Check the `examples/` directory for sample configurations:

- Basic AWS infrastructure deployment
- Multi-environment setup
- Remote state configuration
- Custom provider configuration

## License

This component is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.
