# Todo Visualization Dashboard

This dashboard provides an interactive visualization of TODOs from your codebase, with filtering by priority and category.

## Features

- Visual charts showing distribution of TODOs by priority and category
- Interactive filtering by priority and category
- Detailed table view of all TODOs
- Stacked bar chart showing priority distribution across categories
- File-based analysis showing which files have the most TODOs

## Getting Started

### Option 1: Use Sample Data

1. Open `index.html` in your web browser
2. Click the "Load Sample Data" button to load a set of example TODOs

### Option 2: Use Your Own TODOs

1. Generate a JSON file from your codebase using the `generate-json.ts` script:

   ```bash
   # Compile the script
   npx tsc examples/generate-json.ts --esModuleInterop --target ES2020 --module commonjs
   
   # Run the script with your file patterns
   node examples/generate-json.js "src/**/*.ts" "src/**/*.js"
   ```

2. Open `index.html` in your web browser
3. Click "Upload Todos JSON" and select the generated `todos.json` file

## Dashboard Components

### Priority Distribution

A pie chart showing the distribution of TODOs by priority level (Critical, High, Medium, Low, Unknown).

### Category Distribution

A bar chart showing the most common categories found in your TODOs.

### Files with Most TODOs

A horizontal bar chart showing which files in your codebase have the most TODOs.

### Priority by Category

A stacked bar chart showing how priorities are distributed across the top categories.

### Todo Items Table

A detailed table view of all TODOs, sorted by priority, with filtering capabilities.

## Filtering

You can filter the dashboard data by:

1. **Priority**: Show only TODOs with a specific priority level
2. **Category**: Show only TODOs with a specific category

Filters can be combined to narrow down the displayed TODOs.

## Extending the Dashboard

This dashboard is built with standard HTML, CSS, and JavaScript using the Chart.js library. You can extend it by:

1. Adding more visualizations
2. Enhancing the filtering capabilities
3. Adding export functionality
4. Implementing a backend service for real-time updates
5. Integrating with project management tools

## Implementation Details

The dashboard is implemented as a standalone HTML file with no server requirements. It uses:

- Chart.js for data visualization
- Vanilla JavaScript for data processing and DOM manipulation
- CSS Grid and Flexbox for responsive layout

The data processing is done entirely in the browser, making it easy to deploy and use.