# Getting Started with BFCI Components

This guide will walk you through the process of setting up and using BFCI Components in your project.

## Prerequisites

- GitLab account with access to the BFCI Components repository
- Node.js 18+ installed
- npm 8+ installed

## Installation

1. Add the component registry to your project's `.gitlab - ci.yml`:

```yaml
include:
  - project: 'Blueflyio / internal - projects / llm / bfcicomponents'
    ref: main
    file: 'docs / ci - templates / shared.yml'
```text

2. Install the npm package:

```bash
npm install @bfci / components
```text

## Basic Usage
Here's an example of how to use a BFCI Component in your `.gitlab - ci.yml`:

```yaml
include:
  - component: registry.gitlab.bluefly.io / Blueflyio / internal - projects / llm / bfcicomponents / test@1.0.0
    inputs:
      test_command: 'npm test'
      coverage_path: 'coverage'
```text

## Configuration
Each component has its own configuration options. Check the [Components Section](.. / components / ) for detailed information about each component's configuration.

## Best Practices
1. Always pin component versions to ensure stability
2. Use semantic versioning for your components
3. Test components in a staging environment before deploying to production
4. Keep your component registry up to date

## Next Steps
- Explore the [Components Section](.. / components / ) to learn about available components
- Check out the [Configuration Guide](. / configuration.md) for advanced usage
- Join our [Community Forum](https://gitlab.bluefly.io / Blueflyio / internal - projects / llm / bfcicomponents/ - /issues) for support and discussions
