# Shared ESLint Configuration

This package provides a shared ESLint configuration for Bluefly projects. It includes configurations for TypeScript, React, and modern JavaScript best practices.

## Features

- TypeScript support with strict type checking
- React and JSX support
- Import / export validation and ordering
- Modern JavaScript best practices
- Accessibility checks
- Prettier integration
- Test - specific rule overrides

## Installation

1. Install the required dependencies in your project:

```bash
npm install --save - dev eslint @typescript - eslint / parser @typescript - eslint / eslint - plugin eslint - plugin - react eslint - plugin - react - hooks eslint - plugin - jsx - a11y eslint - plugin - import eslint - plugin - prettier prettier
```text

2. Create or update your project's `.eslintrc.js`:

```javascript
module.exports  =  {
  extends: ['@bluefly / eslint - config'],
  parserOptions: {
    project: '. / tsconfig.json',
  },
  rules: [// Project - specific rule overrides],
};
```text

## Usage
The configuration can be used in your project by extending it in your local `.eslintrc.js`file. You can override specific rules as needed while maintaining a consistent base configuration.

### Example Project Configuration

```javascript
module.exports  =  {
  extends: ['@bluefly / eslint - config'],
  parserOptions: {
    project: '. / tsconfig.json',
  },
  rules: {
    // Project - specific rule overrides
    '@typescript - eslint / no - explicit - any': 'error',
    'no - console': 'off',
  },
  overrides: [
    {
      files: [' * .js'],
      rules: {
        '@typescript - eslint / no - var - requires': 'off',
      },
    },
  ],
};
```text

## Testing
The package includes test files to verify that the ESLint configuration works as expected. To run the tests:

```bash
npm test
```text

## Contributing
When contributing to this package, please ensure that:

1. All new rules are thoroughly tested
2. Documentation is updated
3. Changes are backward compatible
4. Tests pass

## License
This package is licensed under the MIT License.
