# MCP Server Component

This component provides setup and management for Model Context Protocol (MCP) servers, supporting both local and Google Drive configurations.

## Inputs

| Name | Type | Required | Default | Description |
|------|------|----------|---------|-------------|
| stage | string | true | - | Stage in which to run this component |
| image | string | true | node:20-alpine | Docker image to use |
| server_type | string | true | local | Type of MCP server (local or gdrive) |
| debug | boolean | false | false | Enable debug mode |
| verbose | boolean | false | false | Enable verbose output |
| auth_required | boolean | false | false | Whether authentication is required |
| project_path | string | false | ./llm-mcp | Path to the MCP project |
| sdk_version | string | false | latest | Version of @modelcontextprotocol/sdk to install |
| fix_mode | boolean | false | false | Enable fix mode to automatically resolve common issues |

## Usage

### Basic Usage

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/llm/bfcicomponents/mcp-server@1.0.0
    inputs:
      stage: setup
      server_type: local
```

### With Fix Mode

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/llm/bfcicomponents/mcp-server@1.0.0
    inputs:
      stage: setup
      server_type: local
      fix_mode: true
      debug: true
```

### Google Drive Configuration

```yaml
include:
  - component: gitlab.bluefly.io/blueflyio/internal-projects/llm/bfcicomponents/mcp-server@1.0.0
    inputs:
      stage: setup
      server_type: gdrive
      auth_required: true
      fix_mode: true
```

## Common Issues and Solutions

### Missing Build Output

If `dist/index.js` is missing:
1. Enable fix_mode to automatically rebuild
2. Check build logs for errors
3. Verify all dependencies are installed

### SDK Not Found

If @modelcontextprotocol/sdk is missing:
1. Enable fix_mode to reinstall the SDK
2. Verify the SDK version is correct
3. Check network connectivity to npm registry

### Authentication Issues

For Google Drive MCP server:
1. Set auth_required: true
2. Enable fix_mode to run auth setup
3. Verify auth.json is present

## Debugging

Enable debug mode to get detailed information about:
- Environment setup
- Dependency installation
- Build process
- Server startup

## Artifacts

The component generates the following artifacts:
- dist/ directory
- node_modules/
- package.json
- package-lock.json
- logs/ (if available) 