-- LLM Platform Database Schema Migration
-- Version: 1.0.0
-- Creation of Models and ModelVersions tables

-- Use transactions for safe schema changes
START TRANSACTION;

-- Create Models table
CREATE TABLE IF NOT EXISTS models (
    id INTEGER PRIMARY KEY AUTO_INCREMENT,
    name VARCHAR(100) NOT NULL UNIQUE,
    provider VARCHAR(50) NOT NULL,
    base_model VARCHAR(100) NOT NULL,
    description TEXT NULL,
    capabilities JSON NULL,
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    is_active BOOLEAN NOT NULL DEFAULT TRUE
) ENGINE=InnoDB;

-- Create indexes for Models table
CREATE UNIQUE INDEX idx_model_name ON models(name);
CREATE INDEX idx_provider ON models(provider);
CREATE INDEX idx_base_model ON models(base_model);
CREATE INDEX idx_is_active ON models(is_active);

-- Create ModelVersions table
CREATE TABLE IF NOT EXISTS model_versions (
    id INTEGER PRIMARY KEY AUTO_INCREMENT,
    model_id INTEGER NOT NULL,
    version VARCHAR(50) NOT NULL,
    parameters BIGINT NULL,
    context_window INTEGER NULL,
    input_token_cost DECIMAL(10,6) NULL,
    output_token_cost DECIMAL(10,6) NULL,
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    is_default BOOLEAN NOT NULL DEFAULT FALSE,
    
    -- Define the foreign key relationship
    CONSTRAINT fk_model_version FOREIGN KEY (model_id) 
        REFERENCES models(id) ON DELETE CASCADE
);

-- Create indexes for ModelVersions table
CREATE UNIQUE INDEX idx_model_version ON model_versions(model_id, version);
CREATE INDEX idx_is_default ON model_versions(is_default);

COMMIT;