-- LLM Platform Database Schema Migration
-- Version: 1.0.0
-- Creation of Deployments table

-- Use transactions for safe schema changes
START TRANSACTION;

-- Create Deployments table
CREATE TABLE IF NOT EXISTS deployments (
    id INTEGER PRIMARY KEY AUTO_INCREMENT,
    name VARCHAR(100) NOT NULL UNIQUE,
    model_id INTEGER NOT NULL,
    model_version_id INTEGER NOT NULL,
    status VARCHAR(20) NOT NULL DEFAULT 'provisioning',
    environment VARCHAR(20) NOT NULL,
    endpoint VARCHAR(255) NOT NULL,
    scaling JSON NOT NULL,
    config JSON NOT NULL,
    created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    created_by VARCHAR(100) NOT NULL,
    
    -- Define the foreign key relationships
    CONSTRAINT fk_deployment_model FOREIGN KEY (model_id) 
        REFERENCES models(id) ON DELETE RESTRICT,
    CONSTRAINT fk_deployment_model_version FOREIGN KEY (model_version_id) 
        REFERENCES model_versions(id) ON DELETE RESTRICT
);

-- Create indexes for Deployments table
CREATE UNIQUE INDEX idx_deployment_name ON deployments(name);
CREATE INDEX idx_deployment_model ON deployments(model_id);
CREATE INDEX idx_deployment_status ON deployments(status);
CREATE INDEX idx_deployment_environment ON deployments(environment);

COMMIT;