---
id: database_schemas-migrations-README
---
# LLM Platform Database Migration Files

This directory contains SQL migration files for creating and populating the LLM Platform database schema.

## Files

1. `01_create_llm_platform_tables.sql` - Creates the Models and ModelVersions tables with appropriate indexes and relationships
2. `02_insert_sample_data.sql` - Populates the tables with sample data for testing and development

## How to Use

### Prerequisites

- MySQL 5.7+ or MariaDB 10.2+
- Database user with CREATE, ALTER, and INSERT privileges

### Running the Migrations

You can run these migrations using the MySQL command line client or a database management tool like phpMyAdmin, MySQL Workbench, or DBeaver.

#### Using MySQL Command Line

```bash
# Connect to your MySQL server
mysql -u username -p

# Select your database
USE your_database_name;

# Run the migrations
SOURCE /path/to/01_create_llm_platform_tables.sql;
SOURCE /path/to/02_insert_sample_data.sql;
```

#### Using a Database Management Tool

1. Open your database management tool
2. Connect to your database
3. Open the SQL script file
4. Execute the script

### Verification

After running the migrations, you can verify that the tables were created correctly by running:

```sql
SHOW TABLES;
DESCRIBE models;
DESCRIBE model_versions;
SELECT COUNT(*) FROM models;
SELECT COUNT(*) FROM model_versions;
```

## Sample Queries

See the `../query_examples.sql` file for examples of how to query the database schema.

## Rollback

If you need to roll back the migrations, you can use the following SQL:

```sql
DROP TABLE IF EXISTS model_versions;
DROP TABLE IF EXISTS models;
```

## Next Steps

- Set up appropriate user permissions for the tables
- Configure backup procedures
- Implement monitoring for query performance
- Consider adding additional tables for Deployments as shown in the ERD

## Maintenance

- Regularly monitor the size of these tables
- Consider archiving old model versions if the table grows too large
- Use EXPLAIN to optimize queries as needed

---

**Version**: 1.0.0  
**Last Updated**: May 31, 2025
