---
id: development-README-template
---
# Standardized README Template

This template ensures consistent documentation across all LLM Platform AI platform projects.

## Header Format

```markdown
# Project Name - Brief Description

**Status**: [STATUS_BADGE] - [STATUS_DESCRIPTION]  
**Innovation Score**: [CURRENT]/100 → Target: [TARGET]/100  
**Documentation**: [Central Documentation Hub](../bfdocs/docs/[CATEGORY]/[PROJECT]/)

---

[Detailed project description]
```

## Status Badges

### Production Ready
```markdown
**Status**: ✅ **PRODUCTION READY** - 95/100 Innovation Score - Ready for release
```

### Fixable/Development
```markdown
**Status**: 🔧 **FIXABLE** - 60% working, estimated X days to production ready
```

### Archived/Abandoned
```markdown
**Status**: ⚠️ **ARCHIVED** - Deliberately abandoned in favor of strategic focus
**Alternative**: [Alternative solution description]
```

## Required Sections

### 1. Status Section
Always include current reality:
- What actually works
- What needs fixing (be specific)
- Time estimates for fixes
- Strategic value/reasoning

### 2. Quick Start
```markdown
## Quick Start

### Installation
[Installation commands]

### Basic Usage
[Basic usage examples]

### Documentation
For complete documentation, see [Central Hub](../bfdocs/docs/README)
```

### 3. Links to Central Documentation
Always link to the centralized documentation in bfdocs:
```markdown
**Full Documentation**: [Project Docs](../bfdocs/docs/[category]/[project]/)
**Platform Overview**: [Platform Documentation](../bfdocs/docs/README)
```

## Documentation Categories

- **modules/production/**: Production-ready Drupal modules (85%+ complete)
- **modules/development/**: Development modules (50-85% complete)  
- **modules/archived/**: Archived/deprecated modules
- **packages/production/**: Production-ready NPM packages
- **packages/development/**: Fixable NPM packages
- **packages/archived/**: Abandoned NPM packages

## Innovation Score Guidelines

- **90-100**: Production ready, Drupal.org ready, enterprise deployment
- **75-89**: Near production, minor fixes needed
- **50-74**: Development stage, functional but needs work
- **25-49**: Early development, significant work needed
- **0-24**: Concept/stub, major implementation required

## Strategic Status Guidelines

### Production Ready ✅
- All tests pass
- Documentation complete
- Real functionality (not stubs)
- Performance validated
- Security reviewed

### Fixable 🔧  
- Core architecture solid
- Specific known issues
- Realistic fix timeline (days, not weeks)
- Clear business value

### Archived ⚠️
- Strategic decision to abandon
- Resources better used elsewhere
- Alternative solution exists
- Clear migration path

## Example: Good README Header

```markdown
# LLM Module - Enterprise AI Platform

**Status**: ✅ **PRODUCTION READY** - 90/100 Innovation Score  
**Achievement**: Multi-model support with compliance framework  
**Documentation**: [Central Documentation Hub](../bfdocs/docs/modules/production/llm/)

---

Enterprise LLM platform with multi-model support, token management, audit logging, and compliance features. Integrates with Ollama for private model hosting and supports OpenAI/Anthropic for cloud deployment.

## 🎯 Production Status

- ✅ **Multi-model support** (OpenAI, Anthropic, Ollama)
- ✅ **Token usage tracking** with cost analysis
- ✅ **Audit logging** with compliance features  
- ✅ **Performance monitoring** and benchmarking
- ✅ **Real AI integration** (not stubs)
```

## Anti-Patterns to Avoid

❌ **Don't**: Claim features that don't work  
❌ **Don't**: Hide problems or broken functionality  
❌ **Don't**: Use vague status descriptions  
❌ **Don't**: Skip central documentation links  
❌ **Don't**: Duplicate documentation content  

✅ **Do**: Be honest about current state  
✅ **Do**: Provide specific fix timelines  
✅ **Do**: Link to central documentation  
✅ **Do**: Use consistent formatting  
✅ **Do**: Focus on value proposition  

This template ensures professional, honest, and consistent documentation across the entire platform.
