---
id: integration-drupal
---
# Drupal LLM Platform Recipe

The `llm_platform_recipe` is a Drupal 11 recipe that provides:

- Complete foundation for building AI-powered applications
- Integration with the entire LLM Platform ecosystem
- Advanced project intelligence capabilities
- Interactive UI components
- Real-time dashboard system
- Progressive assessment workflow
- Visual upgrade readiness timeline

## Key Components

```php
// Core services with dependency injection
src/Service/
├── ProviderHealthMonitor.php      # Health monitoring and failover
├── RealtimeUpdateService.php      # WebSocket and live updates
├── llmcliIntegrationService.php    # CLI tool integration
├── MetricsService.php             # Performance and analytics
└── LivingRecipeEngine.php         # Neural-enhanced recipe management
```

```javascript
// Client-side interactive components
js/
├── realtime-dashboard.js          # Real-time dashboard functionality
├── interactive-phases.js          # Phase management with drag-drop
├── progressive-assessment.js      # Multi-step assessment wizard
└── upgrade-timeline.js            # Interactive timeline visualization
```

## Full Suite of Drupal AI Platform Modules

> **Note:** The following modules are maintained as separate repositories, not as a monorepo. Each is focused on AI integration, migration, or enterprise features for Drupal 11+.

### Canonical List of Drupal AI Platform Modules

- **ai_swarm_intelligence**
  - code_genesis
  - project_intelligence
- **alternative_services**
  - (core module only)
- **api_normalization**
  - ai_entity_deriver
  - api_normalization_cache
  - api_normalization_schema
  - api_normalization_transform
  - api_normalization_versioning
- **blockchain_manager**
  - AIBlockchainAnalyzer (plugin)
  - BlockchainProvider (plugin)
  - ContractTemplate (plugin)
- **drupal_migration_plus**
  - drupal_migration_plus_experience_builder
  - drupal_migration_plus_aem
  - drupal_migration_plus_html
  - drupal_migration_plus_sitecore
  - drupal_migration_plus_themes
  - drupal_migration_plus_ai
  - drupal_migration_plus_wordpress
  - drupal_migration_plus_enterprise
  - drupal_migration_plus_joomla
  - drupal_migration_plus_react
- **experience_builder_converter**
  - eb_layout_builder_migration
  - eb_paragraphs_migration
- **field_eca_bridge**
  - field_eca_bridge_examples
- **langchain**
  - langchain_ai
  - langchain_eca
  - langfuse_observability
  - langgraph
  - llm_adapter
  - llm_insights
- **llm**
  - llm_ai
  - llm_ai_integration
  - llm_anthropic
  - llm_eca
  - llm_embeddings
  - llm_fleet_registry
  - llm_insights
  - llm_integrations
  - llm_local
  - llm_mcp
  - llm_mock
  - llm_openai
  - llm_openapi
  - llm_orchestration
  - llm_platform_insights
  - llm_search
  - llm_testing
  - llm_ui
  - llm_vector
- **marketplace_integration**
  - (core module only)
- **mcp_client_extras**
  - mcp_ai_platform
  - mcp_analytics_pro
  - mcp_integration_hub
  - mcp_workflow_engine
- **multitenancy**
  - (core module only)
- **recipe_onboarding**
  - (core module only)
- **secure_drupal**
  - authentication
  - compliance
  - compliance_framework
  - openapi_compliance_enforcer
  - password-policy
  - policy_bridge
  - release_evidence
  - resources
  - secure_accessibility
  - secure_ai_compliance
  - secure_audit
  - secure_auth
  - secure_compliance
  - secure_compliance_profile
  - secure_config
  - secure_controls
  - secure_core
  - secure_drupal_healing_logging
  - secure_eca
  - secure_evidence_config
  - secure_evidence_dblog
  - secure_evidence_log
  - secure_fedramp
  - secure_headers
  - secure_pci
  - secure_zero_trust
  - separation_of_duties
  - theme_security
