---
id: llm-integration
---
# LLM Platform Integration Guide

This document provides integration guidelines specific to the LLM Platform module.

## Integration with Other Modules

The LLM Platform module integrates with various other modules through standardized interfaces and patterns.

### Primary Integration Points

- **AI Swarm Intelligence** - Integration via the `SwarmLlmBridge` service
- **Field ECA Bridge** - Integration through ECA conditions and actions
- **Secure Drupal** - Security policy implementation and validation
- **LangChain** - Extended model capabilities and chain execution

## Implementation Details

### SwarmLlmBridge

The `SwarmLlmBridge` class implements the `AiSwarmLlmBridgeInterface` and provides:

- Model selection for swarm agents
- Token usage tracking for swarm operations
- Event propagation between LLM and Swarm modules

### ECA Integration

LLM-specific ECA components include:

- Conditions for model capability checks
- Actions for model inference and agent execution
- Events for completion and error handling

## Shared Services

- `llm.platform` - Core platform service with unified API
- `llm.token_usage_tracker` - Token usage tracking and reporting
- `llm.model_selector` - Intelligent model selection service

## Reference Documentation

For more information, see:

- [Integration Patterns](../integration/patterns)
- [Integration Code Quality Checklist](../integration/code-quality)
- [Service Naming Conventions](../integration/service-naming-conventions)
