# CI/CD Quality Gates

This project enforces strict quality gates in the GitLab CI/CD pipeline to ensure production-grade standards for all code, APIs, and models.

## Enforced Quality Gates

### 1. OpenAPI Linting
- **Tool:** Spectral (`openapi_lint`, `validate_openapi`)
- **Scope:** All OpenAPI 3.1 specs in `openapi/`
- **Failure:** Pipeline fails on any spec error or warning

### 2. Test Coverage
- **Tool:** Jest (`test_coverage`)
- **Threshold:** 95%+ line coverage required
- **Failure:** Pipeline fails if coverage < 95%
- **Artifact:** Coverage summary in `coverage/`

### 3. Linting
- **JavaScript/TypeScript:** ESLint (`eslint_check`)
- **PHP/Drupal:** PHPCS (`phpcs_lint`, Drupal standard)
- **Failure:** Pipeline fails on lint errors

### 4. Security
- **Node.js:** npm audit (`npm_audit`, high severity)
- **Python:** Bandit (`bandit_security`)
- **PHP/Drupal:** Composer audit (manual/optional)
- **Failure:** Pipeline fails on vulnerabilities

### 5. Accessibility
- **Tool:** pa11y-ci (`accessibility_check`)
- **Scope:** All public pages via sitemap
- **Failure:** Pipeline fails on accessibility violations

### 6. Performance
- **Tool:** Lighthouse CI (`performance_check`)
- **Threshold:** Performance score >= 90
- **Failure:** Pipeline fails if score < 90

### 7. MLflow Integration
- **Jobs:** Model registration, reporting, and MLflow UI build/deploy
- **Scope:** All model artifacts and registry actions
- **Failure:** Pipeline fails on registration or reporting errors

---

All jobs are required for merge and deployment. For details, see `.gitlab-ci.yml` and `ROADMAP.md`. 