---
id: modules-development-drupal_migration_plus-FIELD_MAPPING_TUTORIAL
---
# Field Mapping with Experience Builder

This tutorial guides you through the process of using the Experience Builder interface for field analysis and mapping in Drupal Migration Plus.

## Prerequisites

- Drupal Migration Plus installed and configured
- Source database connection configured
- `drupal_migration_plus_experience_builder` module enabled
- Access to the Drupal administrative interface

## Accessing the Field Mapping Interface

1. Log in to your Drupal site as an administrator
2. Navigate to **Content → Migration → Drupal Migration Plus**
3. Click on **Field Mapping** in the main navigation
4. Select your source system type (e.g., Drupal 7, WordPress, Joomla)

## Running Field Analysis

The field analysis process examines your source content and suggests optimal field mappings to your target content types.

### Step 1: Select Source Content Type

1. From the dropdown, select the source content type you want to analyze
   - For Drupal: Choose from available node types (e.g., Article, Basic Page)
   - For WordPress: Choose from post types (e.g., Post, Page, Custom Post Types)
   - For Joomla: Choose from available content categories

### Step 2: Select Target Content Type

1. From the dropdown, select the Drupal content type you want to migrate to
   - You can select an existing content type
   - Or choose "Create New" to generate a new content type based on the source

### Step 3: Configure Analysis Options

1. Click on **Analysis Options** to expand additional settings
2. Configure the following options:
   - **Analysis Depth**: Basic, Standard, or Deep
   - **Include Field Collection Analysis**: Yes/No (Drupal 7 only)
   - **Include Entity Reference Analysis**: Yes/No
   - **Include Media Analysis**: Yes/No
   - **AI-Powered Analysis**: Enable/Disable (requires AI module)

### Step 4: Run Analysis

1. Click the **Analyze Fields** button
2. The system will process your request (this may take a few minutes for complex content types)
3. Progress will be displayed during analysis

## Understanding Analysis Results

The analysis results are displayed in a visual interface with color-coded suggestions:

### Field Mapping Visualization

- **Green**: High-confidence direct mappings (90%+ confidence)
- **Yellow**: Medium-confidence mappings (70-89% confidence)
- **Red**: Low-confidence or problematic mappings (<70% confidence)
- **Blue**: AI-suggested transformations or concatenations

### Field Type Compatibility

For each suggested mapping, you'll see:
- Source field type
- Target field type
- Compatibility score
- Required transformations

### Field Data Preview

The system shows sample data from your source to help you verify mapping suggestions:
- Sample values from source content
- Transformed preview in target format
- Potential data loss warnings

## Creating Field Mappings

### Step 1: Using the Visual Mapper

1. In the central canvas area, you'll see source fields on the left and target fields on the right
2. Drag source fields and drop them onto corresponding target fields
3. Lines will connect mapped fields with color coding based on compatibility

### Step 2: Configure Field Transformations

For fields that require transformation:

1. Click on the mapping line to open the transformation panel
2. Select from available transformation options:
   - **Direct**: Simple copy with basic type conversion
   - **Transform**: Apply specific transformations
   - **Split/Combine**: Break apart or combine field values
   - **Custom**: Write custom transformation code

### Step 3: Field-Specific Options

Different field types have specialized options:

#### Text Fields
- Text format conversion
- HTML filtering options
- Length handling (truncation or expansion)

#### Entity Reference Fields
- Reference resolution method
- Create new entities option
- Missing reference handling

#### File/Image Fields
- File path handling
- ALT/Title attribute mapping
- Image style conversion

#### Date Fields
- Date format conversion
- Timezone handling
- Range conversion

### Step 4: Preview Mapping Results

1. After configuring mappings, click **Preview Results**
2. The system will process sample content and show how it would appear after migration
3. Review the preview and make adjustments as needed

### Step 5: Save Mapping Configuration

1. Once satisfied with your mappings, click **Save Configuration**
2. Provide a name for this mapping configuration
3. Optionally add notes or description
4. Click **Save**

## Advanced Features

### Using AI for Complex Mappings

If you've enabled the AI integration:

1. Click the **AI Suggestions** button for specific fields
2. The system will analyze the content and suggest:
   - Field transformations
   - Content restructuring
   - Pattern-based mappings
   - Data cleanup suggestions

### Handling Custom Field Types

For custom or complex field types:

1. Click **Advanced Mapping** in the field options
2. Use the field mapping scripting interface to define:
   - Custom extraction logic
   - Data transformation rules
   - Validation requirements

### Creating Field Mapping Templates

To reuse your mapping configuration:

1. After saving a configuration, click **Create Template**
2. Select the elements to include in the template
3. Provide a name and description
4. Save the template for future use

## Using Saved Mappings

To use your saved mapping configuration:

1. Navigate to **Content → Migration → Execute Migration**
2. Select the content type to migrate
3. Select your saved mapping configuration
4. Configure batch settings
5. Click **Execute Migration**

## Troubleshooting Common Issues

### Missing Fields

If source fields are not appearing:
1. Check field visibility settings in the source system
2. Verify database connection and permissions
3. Try running the analysis with increased depth

### Mapping Errors

If you encounter mapping errors:
1. Check field type compatibility
2. Verify that required target fields exist
3. Check for missing dependencies
4. Review transformation logic

### Performance Issues

For large content sets:
1. Reduce analysis depth
2. Use smaller sample sets for initial configuration
3. Enable caching in the module settings
4. Increase PHP memory limits

## Next Steps

After completing your field mapping:

1. Configure migration settings
2. Set up ECA workflows for automation
3. Run test migrations with small datasets
4. Review and refine your configuration
5. Execute the full migration

---

For more information, refer to the [Drupal-to-Drupal Migration Documentation](DRUPAL_TO_DRUPAL_MIGRATION) or the main [User Guide](USER_GUIDE).
