---
id: modules-development-drupal_migration_plus-MODULE_STRUCTURE_DIAGRAM
---
# Drupal Migration Plus Module Structure Diagram

## Current Structure

```
drupal_migration_plus (core)
│
├── drupal_migration_plus_wordpress
├── drupal_migration_plus_aem
├── drupal_migration_plus_html
├── drupal_migration_plus_sitecore
├── drupal_migration_plus_joomla
├── drupal_migration_plus_ai
├── drupal_migration_plus_experience_builder
├── drupal_migration_plus_themes
├── drupal_migration_plus_enterprise
└── migrate_plus
    ├── migrate_example
    ├── migrate_example_advanced
    └── migrate_json_example
```

## Proposed Structure

```
drupal_migration_plus (core)
│
├── migration_sources
│   ├── Plugin
│   │   └── MigrationSource
│   │       ├── WordPressSource
│   │       ├── AemSource
│   │       ├── HtmlSource
│   │       ├── SitecoreSource
│   │       ├── JoomlaSource
│   │       └── DrupalSource
│   └── Service
│       ├── SourceManager
│       └── SourceFactory
│
├── migration_tools
│   ├── Service
│   │   ├── AiOrchestrator
│   │   ├── FieldMappingService
│   │   ├── MigrationRepository
│   │   ├── WorkloadPartitioner
│   │   └── DistributedQueueManager
│   ├── Plugin
│   │   └── MigrateProcess
│   │       ├── FieldCollectionToParagraphs
│   │       ├── AddressFieldMapping
│   │       └── DoubleFieldSplit
│   └── Heuristic
│       ├── ContentEntityHeuristic
│       ├── ConfigEntityHeuristic
│       └── SharedEntityDataHeuristic
│
├── migration_experience_builder
│   ├── Service
│   │   ├── SdcComponentGenerator
│   │   ├── FieldMappingValidator
│   │   ├── FieldTypeConverter
│   │   └── EcaMigrationWorkflowEngine
│   ├── Controller
│   │   └── FieldMappingController
│   └── EventSubscriber
│       └── MigrationEcaSubscriber
│
├── migration_admin_ui
│   ├── Controller
│   │   ├── DashboardController
│   │   ├── MigrationStatusController
│   │   └── VisualMigrationController
│   ├── Form
│   │   ├── SettingsForm
│   │   └── SourceConfigurationForm
│   └── js/components
│       ├── Dashboard
│       ├── FieldMapping
│       └── Visualization
│
└── migration_api
    ├── Controller
    │   ├── ApiController
    │   ├── RecipeController
    │   ├── ConversationalApiController
    │   └── FieldMappingApiController
    ├── Service
    │   ├── ApiNormalizationService
    │   ├── OpenApiIntegrationService
    │   └── ApiSchemaGeneratorService
    └── Normalizer
        ├── MigrationNormalizer
        └── FieldMappingNormalizer
```

## Module Dependency Diagram

```
                      +---------------------+
                      | drupal_migration_plus |
                      +----------+----------+
                                 |
                                 v
        +--------------------+---+---+--------------------+
        |                    |       |                    |
        v                    v       v                    v
+---------------+   +----------------+   +----------------+   +----------------+
|migration_sources|   |migration_tools |   | migration_api  |   |migration_admin_ui|
+-------+-------+   +----------------+   +----------------+   +----------------+
        |                    ^                                          ^
        |                    |                                          |
        |                    |                                          |
        |                    |                                          |
        |           +--------+--------+                                 |
        |           |                 |                                 |
        +---------->|migration_experience_builder+--------------------+
                    |                 |
                    +-----------------+
```

## Plugin System Architecture

```
+-------------------+       +-------------------+
| SourceManager     |<----->| MigrationSource   |
| (Plugin Manager)  |       | (Plugin Interface)|
+-------------------+       +-------------------+
         ^                           ^
         |                           |
         v                           |
+-------------------+                |
| SourceFactory     |                |
| (Service)         |                |
+-------------------+                |
                                     |
+-------------------+                |
| WordPressSource   |----------------+
| (Plugin)          |                |
+-------------------+                |
                                     |
+-------------------+                |
| AemSource         |----------------+
| (Plugin)          |                |
+-------------------+                |
                                     |
+-------------------+                |
| DrupalSource      |----------------+
| (Plugin)          |                |
+-------------------+                |
                                     |
+-------------------+                |
| SitecoreSource    |----------------+
| (Plugin)          |                |
+-------------------+                |
                                     |
+-------------------+                |
| HtmlSource        |----------------+
| (Plugin)          |                |
+-------------------+                |
                                     |
+-------------------+                |
| JoomlaSource      |----------------+
| (Plugin)          |                |
+-------------------+                |
```

## Service Architecture for migration_tools

```
+-------------------+       +-------------------+
| MigrationRepository|<----->| MigrationClusterer|
+-------------------+       +-------------------+
         ^                           ^
         |                           |
         v                           v
+-------------------+       +-------------------+
| FieldMappingService|<----->| HeuristicManager  |
+-------------------+       +-------------------+
         ^                           ^
         |                           |
         v                           |
+-------------------+                |
| AiOrchestrator    |                |
+-------------------+                |
         ^                           |
         |                           |
         v                           |
+-------------------+                |
| WorkloadPartitioner|               |
+-------------------+                |
         ^                           |
         |                           |
         v                           |
+-------------------+                |
|DistributedQueueManager|           |
+-------------------+                |
                                     |
+-------------------+                |
| ContentEntityHeuristic|------------+
+-------------------+                |
                                     |
+-------------------+                |
| ConfigEntityHeuristic|-------------+
+-------------------+                |
                                     |
+-------------------+                |
|SharedEntityDataHeuristic|-----------+
+-------------------+
```

## Service Architecture for migration_experience_builder

```
+-------------------------+       +-------------------------+
| SdcComponentGenerator   |<----->| FieldMappingValidator   |
+-------------------------+       +-------------------------+
         ^                                 ^
         |                                 |
         v                                 v
+-------------------------+       +-------------------------+
| FieldTypeConverter      |<----->| EcaMigrationWorkflowEngine|
+-------------------------+       +-------------------------+
         ^                                 ^
         |                                 |
         v                                 v
+-------------------------+       +-------------------------+
| FieldMappingController  |<----->| MigrationEcaSubscriber  |
+-------------------------+       +-------------------------+
```

## Service Architecture for migration_api

```
+-------------------------+       +-------------------------+
| ApiController           |<----->| ApiNormalizationService |
+-------------------------+       +-------------------------+
         ^                                 ^
         |                                 |
         v                                 v
+-------------------------+       +-------------------------+
| RecipeController        |<----->| OpenApiIntegrationService|
+-------------------------+       +-------------------------+
         ^                                 ^
         |                                 |
         v                                 v
+-------------------------+       +-------------------------+
| ConversationalApiController|<-->| ApiSchemaGeneratorService|
+-------------------------+       +-------------------------+
         ^                                 ^
         |                                 |
         v                                 v
+-------------------------+       +-------------------------+
| FieldMappingApiController|<---->| MigrationNormalizer     |
+-------------------------+       +-------------------------+
```

## Key Benefits of New Structure

1. **Better Organization**: Logical grouping of related functionality
2. **Improved Extensibility**: Plugin-based architecture for easy extension
3. **Clear Dependencies**: Well-defined module dependencies
4. **Better Developer Experience**: Intuitive architecture with clear responsibilities
5. **Enhanced Maintainability**: Smaller, focused modules that are easier to maintain
6. **Standardized Patterns**: Consistent use of Drupal architecture patterns
