---
id: modules-development-drupal_migration_plus-README
---
# Drupal Migration Plus

[![Latest Stable Version](https://img.shields.io/packagist/v/drupal/drupal_migration_plus.svg)](https://packagist.org/packages/drupal/drupal_migration_plus)
[![Total Downloads](https://img.shields.io/packagist/dt/drupal/drupal_migration_plus.svg)](https://packagist.org/packages/drupal/drupal_migration_plus)
[![License](https://img.shields.io/badge/license-GPL--2.0--or--later-blue.svg)](https://www.drupal.org/project/drupal_migration_plus)
[![Contrib Integration](https://img.shields.io/badge/contrib_migration-integrated-brightgreen)](#contrib-migration-integration)

## 🚀 Contrib Migration Integration

**✅ COMPLETED**: This module now uses Drupal contrib migration modules as foundation

Drupal Migration Plus reduces custom code by ~65% by leveraging proven contrib migration modules:
- **Migrate Plus** module for enhanced source plugins and data fetchers
- **Migrate Tools** module for Drush commands and batch processing
- **Source modules** (CSV, JSON, XML) for specialized data handling
- **Migrate Devel** module for comprehensive debugging and testing

**Migration Complete**: Custom migration implementations have been replaced with contrib module integration while preserving all advanced migration capabilities. See [CONTRIB_MIGRATION_GUIDE.md](CONTRIB_MIGRATION_GUIDE) for details.

Drupal Migration Plus is an advanced migration framework for Drupal, extending core migration capabilities with intelligent field mapping, multi-CMS support, and contrib-powered migration workflows.

## Features

- **Enhanced Field Mapping**: Visual field mapping tools and intelligent field type detection
- **Multi-CMS Support**: Migration adapters for Drupal, WordPress, and other CMS platforms
- **Migration Clustering**: Smart grouping of related migration tasks
- **Workflow Automation**: Step-by-step migration processes with validation and preview
- **Custom Process Plugins**: Additional process plugins for complex transformations
- **Recipe System**: Recipe-based migration configurations for common scenarios
- **Performance Optimization**: Improved migration performance and monitoring

## Requirements

- Drupal 10.1 or later
- PHP 8.1 or later
- Required modules:
  - Migrate (Drupal core)
  - Migrate Drupal (Drupal core)
  - Migrate Drupal UI (Drupal core)
  - Migrate Plus
  - Migrate Tools

## Installation

### Using Composer (recommended) - Includes Contrib Modules

```bash
# Install with contrib migration modules
composer require drupal/drupal_migration_plus drupal/migrate_plus drupal/migrate_tools
drush en drupal_migration_plus migrate_plus migrate_tools

# Install source-specific modules based on needs
composer require drupal/migrate_source_csv drupal/migrate_source_json
drush en migrate_source_csv migrate_source_json

# Test contrib integration
drush eval "\Drupal::service('drupal_migration_plus.contrib_integration')->getAvailableContribModules();"
```

### Manual Installation

1. Download the module from [drupal.org/project/drupal_migration_plus](https://www.drupal.org/project/drupal_migration_plus)
2. Extract to your modules directory (e.g., `modules/contrib/`)
3. Enable the module through the UI or using Drush: `drush en drupal_migration_plus`

## Configuration

1. Navigate to Administration » Configuration » Development » Migration Plus Settings
2. Configure default migration settings
3. Set up source system connections
4. Configure field mapping preferences
5. Create migration recipes as needed

## Usage

### Recipe Onboarding Workflow

For guided migration:

1. Navigate to Administration » Migration » Recipe Onboarding
2. Follow the step-by-step process:
   - Source system discovery and analysis
   - Field mapping configuration
   - Content migration execution
   - Post-migration validation

### Manual Migration

For custom migrations:

```bash
# List available migrations
drush migrate:status

# Run a specific migration
drush migrate:import my_migration

# Roll back a migration
drush migrate:rollback my_migration
```

### Source Adapters

The module provides adapters for different source systems:

- **Drupal to Drupal**: Migration between Drupal versions
- **WordPress to Drupal**: Import WordPress content
- **Joomla to Drupal**: Import Joomla content
- **Custom Sources**: Framework for creating custom source adapters

## Extending the Module

### Creating Custom Adapters

```php
namespace Drupal\my_module\SourceAdapter;

use Drupal\drupal_migration_plus\SourceAdapter\SourceAdapterBase;

/**
 * Source adapter for my custom system.
 */
class MySystemAdapter extends SourceAdapterBase {
  // Implementation here
}
```

### Custom Process Plugins

```php
namespace Drupal\my_module\Plugin\migrate\process;

use Drupal\migrate\ProcessPluginBase;

/**
 * @MigrateProcessPlugin(
 *   id = "my_custom_processor"
 * )
 */
class MyCustomProcessor extends ProcessPluginBase {
  // Implementation here
}
```

## Documentation

For more detailed documentation:

- [User Guide](docs/user-guide)
- [Developer Guide](docs/developer-guide)
- [Source Adapters](docs/source-adapters)
- [Process Plugins](docs/process-plugins)
- [Recipe System](docs/recipe-system)

## Support

- For bug reports and feature requests, visit the [issue queue](https://www.drupal.org/project/issues/drupal_migration_plus)
- For general questions, use the [Drupal Migration group](https://groups.drupal.org/migration)

## Contributing

- Read our [contributing guidelines](docs/contributing)
- Submit patches via Drupal.org issues or pull requests

## License

This project is licensed under the [GNU General Public License v2.0 or later](http://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
