---
id: modules-development-drupal_migration_plus-RECIPE_ONBOARDING
---
# Recipe Onboarding: User Guide

## Introduction

Recipe Onboarding is a comprehensive, step-by-step workflow that guides you through migrating any website to Drupal 11. This feature combines AI-powered analysis, field mapping, theme migration, and self-healing workflows to create an end-to-end migration experience.

**Author**: Thomas Scola (fluc423 on Drupal.org), founder of LLM Platform.io and the LLM Platform Collective

## Getting Started

### Prerequisites

Before starting the Recipe Onboarding workflow, ensure you have:

1. **Source Website Access**: Either database credentials or URL access to the source website
2. **Drupal 11 Installation**: A working Drupal 11 site with Drupal Migration Plus installed
3. **Required Modules**: All dependencies including ECA (Event-Condition-Action) and AI modules
4. **Sufficient Permissions**: Administrator access to your Drupal 11 site

### Accessing Recipe Onboarding

Navigate to **Administration → Migration → Recipe Onboarding** (`/admin/migrate/plus/recipe-onboarding`) to start the workflow.

## The Recipe Onboarding Workflow

The Recipe Onboarding process consists of eight integrated steps that guide you from source discovery to a fully migrated site:

### 1. Source Discovery

This step analyzes your source website to determine its CMS platform, content structure, and available data.

**Features:**
- **Automatic CMS Detection**: Identifies WordPress, Drupal 7, Joomla, and other common platforms
- **Content Analysis**: Inventories content types, taxonomies, users, and media
- **Schema Inspection**: Examines database structure for custom fields and relationships

**How to Use:**
1. Enter the URL or database connection information for your source site
2. Click "Discover Source" to initiate the analysis
3. Review the detected CMS information and content inventory
4. Continue to Content Planning when ready

### 2. Content Planning

This step helps you plan how your source content will map to Drupal 11 entities and structures.

**Features:**
- **Content Type Mapping**: Suggest Drupal content types for source content
- **Taxonomy Planning**: Identify and map taxonomy vocabulary structures
- **Entity Relationship Mapping**: Plan how content relationships will be preserved
- **AI Recommendations**: Get suggestions for optimal content architecture

**How to Use:**
1. Review AI-suggested content type mappings
2. Adjust any mappings that don't match your needs
3. Configure taxonomy structures
4. Define entity relationships
5. Continue to Field Mapping when your content plan is complete

### 3. Field Mapping

This step provides a powerful interface for mapping source fields to Drupal fields with AI assistance.

**Features:**
- **AI Field Analysis**: Automatically analyzes source fields and suggests mappings
- **Confidence Scoring**: Each mapping includes a confidence score to guide your decisions
- **Field Transformation**: Apply transformations to convert data during migration
- **Data Preview**: See how source data will appear in Drupal fields
- **Validation**: Real-time validation of field mappings

**How to Use:**
1. Review AI-suggested field mappings organized by content type
2. Adjust mappings with low confidence scores
3. Add any custom transformations needed
4. Validate mappings to ensure compatibility
5. Continue to Theme Migration when field mapping is complete

### 4. Theme Migration

This step analyzes your source website's visual design and creates a Drupal 11 theme that preserves your brand identity.

**Features:**
- **Visual Analysis**: Uses computer vision to analyze your site's visual appearance
- **Color Palette Extraction**: Identifies and extracts your brand colors
- **Typography System**: Detects and implements your typography hierarchy
- **Component Recognition**: Identifies repeating UI components and patterns
- **Responsive Design**: Creates fully responsive layouts
- **Accessibility Enhancements**: Improves accessibility to WCAG standards
- **Performance Optimization**: Optimizes for Core Web Vitals

**How to Use:**
1. Wait for the visual analysis to complete
2. Review the extracted design elements (colors, typography, components)
3. Select from theme options based on your site's design
4. Customize colors, typography, and component options if needed
5. Preview the theme on different device sizes
6. Generate the theme when you're satisfied with the configuration

### 5. Recipe Configuration

This step configures your migration recipe with detailed settings for how the migration will execute.

**Features:**
- **Basic Recipe Information**: Configure name, description, and version
- **Migration Options**: Set batch size, logging level, and process options
- **Module Requirements**: Select additional modules needed for migration
- **Self-Healing Configuration**: Enable and configure ECA workflows for error handling
- **Recipe Summary**: Review complete configuration before execution

**How to Use:**
1. Configure basic recipe information
2. Set migration options based on your needs
3. Review and select required modules
4. Configure self-healing workflows
5. Review the complete recipe summary
6. Continue to Migration Execution when configuration is complete

### 6. Migration Execution

This step executes the migration recipe and provides real-time monitoring of the process.

**Features:**
- **Real-time Progress Tracking**: Monitor overall progress and individual migrations
- **Detailed Logs**: View detailed logs of the migration process
- **Error Detection**: Identify and troubleshoot migration errors
- **Self-Healing**: Watch as the system automatically repairs detected issues
- **Performance Metrics**: Track migration speed and resource usage
- **Migration Controls**: Pause, resume, or roll back the migration

**How to Use:**
1. Review the migration plan
2. Click "Start Migration" to begin the process
3. Monitor progress and logs during execution
4. Address any errors that cannot be automatically resolved
5. Continue to Post-Migration when the migration is complete

### 7. Post-Migration Validation

This step validates the migration results and identifies any issues that need attention.

**Features:**
- **Content Validation**: Verify migrated content quality and structure
- **Issue Detection**: Identify migration issues categorized by severity
- **Auto-Fix Capabilities**: Automatically fix common issues
- **Validation Metrics**: Score migration quality across different dimensions
- **AI Recommendations**: Get AI-powered suggestions for improvements

**How to Use:**
1. Review validation scores across different dimensions
2. Address detected issues, using auto-fix when available
3. Review fixed issues
4. Generate a migration report for documentation
5. Continue to Completion when validation is satisfactory

### 8. Completion

This final step provides a summary of the migration and guidance for next steps.

**Features:**
- **Migration Summary**: Overview of all migrated content and structures
- **Statistics**: Detailed statistics about the migration
- **Next Steps Guidance**: Instructions for post-migration tasks
- **Resource Links**: Links to helpful documentation and resources
- **Feedback Mechanism**: Provide feedback on the migration process

**How to Use:**
1. Review the migration summary and statistics
2. Follow the suggested next steps to finalize your site
3. Access provided resources for additional guidance
4. Provide feedback on your migration experience
5. Click "Finish" to complete the process and access your new site

## Self-Healing Migration

One of the most powerful features of Recipe Onboarding is its self-healing capability through ECA (Event-Condition-Action) integration.

### How Self-Healing Works

1. **Event Detection**: The system monitors the migration for errors, warnings, and other events
2. **Condition Evaluation**: When an event occurs, conditions evaluate the nature of the issue
3. **Action Execution**: Based on the conditions, appropriate recovery actions are executed
4. **Learning**: The system learns from successful recoveries to improve future migrations

### Self-Healing Workflows

The Recipe Onboarding implements several key ECA workflows:

#### Error Detection Workflow
Identifies errors during migration and categorizes them for appropriate handling.

#### Self-Healing Workflow
Automatically repairs detected issues using AI-powered correction strategies.

#### Validation Workflow
Validates migrated content and configuration against quality standards.

#### Accessibility Workflow
Enhances migrated theme and content to meet WCAG accessibility standards.

## Performance Considerations

Recipe Onboarding is designed to handle large migrations efficiently, but consider these tips for optimal performance:

- **Server Resources**: Ensure adequate CPU, memory, and disk space
- **Batch Size**: Adjust batch size based on content complexity (50-100 items recommended)
- **Database Optimization**: Optimize database settings for both source and target
- **Theme Migration**: Visual analysis is resource-intensive; allocate sufficient memory

## Troubleshooting

### Common Issues

#### Source Analysis Fails
- **Check URL**: Ensure the source URL is accessible
- **Firewall Issues**: Verify your server can access the source site
- **Authentication**: Some sites may require authentication for crawling

#### Field Mapping Issues
- **Field Types**: Verify field types are compatible
- **Required Fields**: Ensure all required fields have mappings
- **Complex Fields**: Special handling may be needed for complex field types

#### Theme Migration Issues
- **Resource Access**: Theme migration requires access to CSS and image resources
- **Browser Rendering**: Some visual elements may render differently
- **Custom Components**: Complex custom components may need manual adjustments

#### Migration Execution Errors
- **Memory Limits**: Increase PHP memory limits for large migrations
- **Timeout Issues**: Increase execution time limits for complex migrations
- **Database Errors**: Check database permissions and table structures

## Best Practices

1. **Start Small**: Test with a smaller content set before full migration
2. **Backup First**: Always backup your target site before starting
3. **Review Mappings**: Carefully review all field mappings, especially low-confidence ones
4. **Test Migration**: After migration, thoroughly test the migrated site
5. **Monitor Performance**: Watch server resources during migration
6. **Document Changes**: Keep notes on any manual adjustments made

## Contributing

The Recipe Onboarding workflow is designed to be extensible. You can contribute by:

- **Adding Source Adapters**: Create adapters for additional CMS platforms
- **Enhancing Field Mappings**: Improve field mapping logic for specific scenarios
- **Contributing ECA Workflows**: Create new self-healing workflows
- **Improving Theme Migration**: Enhance theme analysis and recreation
- **Reporting Issues**: Report bugs or feature requests on the project issue queue

## Technical Architecture

The Recipe Onboarding workflow is built on several key components:

1. **React-based UI**: Modern interface with step-by-step progression
2. **RESTful API**: Backend services for analysis, mapping, and migration
3. **AI Services**: Integration with the Drupal AI module for intelligent processing
4. **ECA Framework**: Event-Condition-Action system for self-healing capabilities
5. **Migration API**: Core Drupal Migration API for data migration
6. **Theme Engine**: Computer vision and CSS analysis for theme migration

By Thomas Scola (fluc423), founder of LLM Platform.io and the LLM Platform Collective
