---
id: modules-development-drupal_migration_plus-USER_GUIDE
---
# User Guide

## Introduction

Drupal Migration Plus is a comprehensive migration platform that helps you migrate content from various CMS platforms to Drupal 11. This guide covers how to use the platform effectively, from initial setup to completing complex migrations.

## Getting Started

### Prerequisites

Before starting a migration, ensure you have:

1. **Source System Access**: Database credentials and file system access to your source CMS
2. **Drupal 11 Site**: A working Drupal 11 installation with Migration Plus installed
3. **Appropriate Permissions**: User account with migration administration permissions
4. **Source Database Backup**: Always backup your source data before migration

### Initial Setup

#### 1. Access the Migration Dashboard

Navigate to `/admin/migrate/plus` to access the main migration dashboard.

#### 2. Configure Source Connection

Go to `/admin/config/migrate/plus/sources` and add your source system:

**WordPress Source Configuration:**
- Database Host: `localhost`
- Database Name: `wordpress_db`
- Username: `db_user`
- Password: `db_password`
- Table Prefix: `wp_`
- Files Path: `/path/to/wordpress/wp-content/uploads`

**Drupal 7 Source Configuration:**
- Database Host: `localhost`
- Database Name: `drupal7_db`
- Username: `db_user`
- Password: `db_password`
- Table Prefix: `drupal_`
- Files Path: `/path/to/drupal7/sites/default/files`

#### 3. Test Connection

Click "Test Connection" to verify your source configuration. You should see a success message and basic site information.

## Field Mapping

### Understanding Field Mapping

Field mapping is the process of connecting fields from your source CMS to fields in your Drupal site. Migration Plus uses AI to analyze your source fields and suggest optimal mappings.

### AI-Powered Field Analysis

#### 1. Start Field Analysis

From the migration dashboard:
1. Select your source system
2. Choose target content type (e.g., "Article")
3. Click "Analyze Fields"

#### 2. Review Analysis Results

The AI analysis provides:

**Direct Mappings**: Fields that can be mapped directly
- Source field: `post_title` → Target field: `title` (Confidence: 95%)
- Source field: `post_content` → Target field: `body` (Confidence: 90%)

**Concatenation Opportunities**: Multiple source fields that should be combined
- `first_name` + `last_name` → `field_full_name`
- Preview: "[first_name] [last_name]"

**Custom Field Conversions**: Complex fields requiring special handling
- WordPress ACF Repeater → Drupal Paragraphs
- Custom Meta Fields → Entity Reference Fields

#### 3. Review Confidence Scores

Each mapping includes a confidence score:
- **High (80-100%)**: Highly confident mapping, minimal review needed
- **Medium (50-79%)**: Good mapping, review recommended
- **Low (0-49%)**: Uncertain mapping, manual review required

### Manual Field Mapping

#### 1. Adjust Mappings

For low-confidence mappings:
1. Click the field mapping row
2. Select the correct target field from dropdown
3. Choose appropriate transformation if needed
4. Save changes

#### 2. Field Concatenation

To combine multiple source fields:
1. Click "Add Concatenation"
2. Select source fields to combine
3. Choose separator (space, comma, dash, etc.)
4. Preview the result
5. Select target field
6. Save concatenation

#### 3. Custom Transformations

For complex data transformations:
1. Select "Custom Transformation"
2. Choose transformation type:
   - **HTML Cleanup**: Remove WordPress/Joomla specific markup
   - **Date Format**: Convert date formats
   - **Media Migration**: Convert to Drupal media entities
   - **Taxonomy Mapping**: Map categories to taxonomy terms

### Validation

#### Real-time Validation

As you configure mappings, the system provides real-time validation:

**Validation Checks:**
- Target field existence
- Data type compatibility
- Required field coverage
- Performance impact assessment

**Validation Results:**
-  Valid mapping with high confidence
-  Warning: Low confidence or performance impact
- ❌ Error: Invalid target field or incompatible types

## Migration Execution

### Pre-Migration Checklist

Before running a migration:

1. **Backup Target Site**: Create a full backup of your Drupal site
2. **Review Field Mappings**: Ensure all important fields are mapped
3. **Test with Small Dataset**: Run a test migration with limited data
4. **Check Dependencies**: Verify required modules are installed
5. **Performance Preparation**: Ensure adequate server resources

### Running a Migration

#### 1. Start Migration

From the migration dashboard:
1. Review your migration plan
2. Set batch size (recommended: 50-100 items per batch)
3. Enable error logging
4. Click "Start Migration"

#### 2. Monitor Progress

The migration dashboard shows:
- **Progress Bar**: Overall completion percentage
- **Processed Items**: Number of items migrated
- **Errors**: Any issues encountered
- **Performance Metrics**: Items per second, memory usage

#### 3. Handle Errors

If errors occur:
1. View error details in the log
2. Address the underlying issue (missing modules, field configuration, etc.)
3. Resume migration from the last successful batch
4. Or rollback and restart if needed

### Post-Migration Tasks

#### 1. Content Review

After migration completion:
- Review migrated content for accuracy
- Check formatting and media files
- Verify user accounts and permissions
- Test functionality and links

#### 2. SEO and URLs

- Run URL alias generation for SEO-friendly URLs
- Set up redirects from old URLs
- Update sitemaps and search engine configurations
- Verify meta tags and structured data

#### 3. Performance Optimization

- Clear all caches
- Run database optimization
- Enable aggregation for CSS/JS
- Configure caching (Redis, Varnish, etc.)

## Common Migration Scenarios

### WordPress to Drupal

#### Blog Migration

**Typical Mappings:**
- Posts → Article content type
- Pages → Basic page content type
- Categories → Taxonomy terms
- Tags → Taxonomy terms
- Comments → Comment entities
- Users → User accounts
- Media → Media entities

**Special Considerations:**
- WordPress shortcodes need cleanup
- Custom post types require custom content types
- Plugin data may need custom migration
- Theme customizations need recreation

#### E-commerce Migration (WooCommerce)

**Additional Mappings:**
- Products → Commerce product entities
- Orders → Commerce order entities
- Customers → Customer profiles
- Coupons → Promotion entities
- Product variations → Product variations

### Drupal 7 to Drupal 11

#### Content Migration

**Core Mappings:**
- Nodes → Nodes (with updated field structures)
- Users → Users (with profile field migration)
- Taxonomy → Taxonomy (with vocabulary updates)
- Files → Media entities (major structural change)
- Comments → Comments (with threading preservation)

**Field Type Updates:**
- Text fields → Text fields (with format migration)
- Image fields → Media reference fields
- File fields → Media reference fields
- Date fields → DateTime fields with timezone
- Node reference → Entity reference

For detailed information on Drupal-to-Drupal migrations, including the Experience Builder integration, field mapping interface, and ECA workflow automation, see the [Drupal-to-Drupal Migration Documentation](DRUPAL_TO_DRUPAL_MIGRATION).

#### Module Data Migration

**Common Modules:**
- Views → Views (with configuration updates)
- Webform → Webform (with form structure migration)
- Field Collection → Paragraphs (structural conversion)
- Organic Groups → Group module
- Flag → Flag (with updated structure)

### Custom CMS Migration

#### Database Analysis

For custom PHP CMS platforms:
1. Analyze database structure
2. Identify content tables and relationships
3. Map content types to Drupal entities
4. Plan field mappings and transformations

#### Data Cleaning

Common data cleaning tasks:
- Remove deprecated HTML tags
- Normalize date formats
- Clean up encoded characters
- Validate email addresses and URLs
- Remove or convert proprietary markup

## Advanced Features

### AI Content Enhancement

#### Automatic Content Improvement

Enable AI content enhancement for:
- **SEO Optimization**: Generate meta descriptions and titles
- **Alt Text Generation**: Create alt text for images
- **Content Tagging**: Automatic taxonomy term assignment
- **Quality Assessment**: Identify content that needs review

#### Content Classification

AI can automatically:
- Detect content types based on structure
- Suggest appropriate Drupal content types
- Identify duplicate or similar content
- Recommend content consolidation

### Batch Processing

#### Configuration

Optimize batch processing:
- **Batch Size**: 50-100 items (adjust based on content complexity)
- **Memory Limit**: Increase for large content
- **Time Limit**: Extend for complex transformations
- **Error Handling**: Continue on errors vs. stop on errors

#### Monitoring

Monitor batch processing:
- Memory usage per batch
- Processing time per item
- Error rates and patterns
- Database query performance

### Custom Migrations

#### Creating Custom Migration Plugins

For complex data that doesn't fit standard patterns:

1. Create custom source plugin
2. Implement custom process plugins
3. Configure destination mappings
4. Add validation and error handling

#### Migration Dependencies

Handle migration dependencies:
- User migration before content
- Taxonomy migration before content with terms
- Media migration before content with media references
- Custom entities before referencing content

## Troubleshooting

### Common Issues

#### Memory Exhaustion

**Symptoms**: "Fatal error: Allowed memory size exhausted"

**Solutions**:
- Increase PHP memory limit
- Reduce batch size
- Enable memory cleanup in processing
- Use more efficient query methods

#### Timeout Issues

**Symptoms**: Script execution timeout during migration

**Solutions**:
- Increase max execution time
- Use smaller batch sizes
- Enable background processing
- Implement proper timeout handling

#### Database Connection Issues

**Symptoms**: "Unable to connect to source database"

**Solutions**:
- Verify database credentials
- Check network connectivity
- Ensure database server is running
- Review firewall settings

#### Field Mapping Errors

**Symptoms**: "Target field does not exist"

**Solutions**:
- Create missing fields in target content type
- Verify field machine names match
- Check field type compatibility
- Update field configurations

### Performance Optimization

#### Database Optimization

- **Indexes**: Ensure proper indexing on source database
- **Query Optimization**: Use efficient queries for large datasets
- **Connection Pooling**: Use persistent database connections
- **Transaction Management**: Batch database operations

#### Memory Management

- **Garbage Collection**: Enable PHP garbage collection
- **Memory Monitoring**: Monitor memory usage patterns
- **Data Chunking**: Process data in smaller chunks
- **Resource Cleanup**: Clean up resources after processing

#### Server Configuration

- **PHP Configuration**: Optimize PHP settings for migration
- **Database Configuration**: Tune database settings
- **Web Server**: Configure appropriate timeouts and limits
- **Caching**: Disable caching during active migration

### Getting Help

#### Documentation Resources

- **Installation Guide**: Setup and configuration instructions
- **API Documentation**: REST API reference and examples
- **Architecture Guide**: Technical architecture overview
- **Troubleshooting Guide**: Common issues and solutions

#### Community Support

- **Issue Queue**: Report bugs and request features
- **Community Forums**: Ask questions and share experiences
- **Documentation**: Contribute to documentation improvements
- **Code Contributions**: Submit patches and enhancements

#### Professional Support

For complex migrations or custom requirements:
- Custom migration development
- Performance optimization consulting
- Training and workshops
- Enterprise support contracts

This user guide provides comprehensive coverage of Migration Plus features and workflows. For additional information, refer to the specific documentation sections or community resources.
