# acrfp Documentation

Welcome to the acrfp (LLM Platform RFP) project documentation. acrfp is an AI-powered application designed to automate and assist in generating Request for Proposal (RFP) responses by leveraging structured opportunity data and integrated LLM workflows.

## Overview

acrfp converts structured opportunity data from sources such as CRM systems, spreadsheets, or GitLab issues into initial proposal drafts. It uses LLMs from the LLM Platform ecosystem (via bfllm and bfapi) to generate content for various RFP sections, ensuring consistency and alignment with company knowledge.

## Features

- Structured data ingestion from multiple sources.
- LLM-powered content generation for RFP sections.
- Template management for consistent proposal formatting.
- GitLab issue integration for RFP lifecycle management.
- Workflow orchestration from data intake to draft output.
- Customizable prompts for tailored content generation.
- Output formatting in common document formats.

## Prerequisites

- Node.js 20.x
- npm 9.x
- Git

## Installation

```bash
git clone https://gitlab.bluefly.io/bluefly/acrfp.git
cd acrfp
npm install
```

## Development

```bash
npm run dev          # Start development server
npm test             # Run tests
npm run lint         # Run linter
npm run typecheck    # Run type checker
```

## Building

```bash
npm run build        # Build for production
npm run build:dev    # Build for development
```

## Testing

```bash
npm test             # Run all tests
npm run test:watch   # Run tests in watch mode
npm run test:coverage # Run tests with coverage
```

## Usage

- Input structured opportunity data via API, file upload, or GitLab issue parsing.
- Generate proposal drafts using integrated LLM workflows.
- Manage RFP progress and versions through GitLab issues.

## Templates

Templates located in the `templates/` directory define proposal structure and branding. They support placeholders filled with generated content.

## GitLab Integration

acrfp integrates with GitLab issues to track RFP opportunities, manage tasks, and store generated content or links.

## Configuration

Configure environment variables for bfapi/bfllm endpoints, GitLab integration, and other services as needed.

## Security and Data Privacy

Sensitive RFP data is handled securely with access controls and data protection measures.

## Error Handling and Logging

Errors during generation are logged and reported for debugging and auditing.

## Contribution

Contributions are welcome. Please follow the contribution guidelines and submit pull requests with tests and documentation updates.

## License

MIT License

## Support

For support, contact [support@bluefly.io](mailto:support@bluefly.io) or open an issue in the GitLab repository.
