# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.2] - 2025-06-03
### Added
- Implemented comprehensive standardized error handling system
  - Added domain-specific error classes hierarchy (NetworkError, TimeoutError, APIError, etc.)
  - Added error codes and categories system
  - Implemented error translation utilities
  - Added helper functions for error type checking (isNetworkError, isServerError, etc.)
- Implemented robust circuit breaker pattern for resilience
  - Added proper state management (CLOSED, OPEN, HALF_OPEN)
  - Implemented configurable failure and success thresholds
  - Added telemetry integration for circuit breaker events
  - Created execution wrapper for simplified usage
- Added comprehensive documentation for error handling and resilience patterns

### Improved
- Enhanced error handling in REST client implementation
- Improved error handling in GraphQL client implementation
- Updated error handling in unified client implementation
- Enhanced overall system resilience with circuit breaker integration

## [1.0.1] - 2025-06-02
### Fixed
- Fixed "path.startsWith is not a function" error in BaseApiClient's buildUrl method
- Added proper type handling for path parameters (string, number, null, undefined)
- Added comprehensive tests for the buildUrl method

### Added
- Enabled advanced retry interceptor with sophisticated exponential backoff
- Added resilient retry interceptor for distributed systems
- Created comprehensive browser compatibility test suite
- Added browser test server for manual testing
- Implemented interactive browser retry tests

### Improved
- Updated method signatures to support a wider range of path parameter types
- Enhanced error handling for edge cases in request path handling
- Improved code quality with better type safety
- Added JSDocs for better code documentation
- Enhanced browser compatibility with detailed testing procedures

## [1.0.0] - 2025-05-29
### Added
- Production-ready API client with comprehensive features
- REST client with type-safe API operations
- GraphQL client with query and mutation support
- Authentication interceptors (JWT, API Key, OAuth)
- Caching system with multiple strategies
- Automatic retry with configurable backoff
- Request/response logging interceptors
- Rate limiting interceptor
- Error handling with standardized error types
- Type definitions for all API operations
- Request batching and concurrency control
- Stream support for large responses
- Integration with OpenTelemetry for tracing
- Comprehensive documentation and examples

### Changed
- Enhanced TypeScript typing system
- Improved error handling with specific error types
- Optimized performance with connection pooling
- Enhanced caching strategies for better performance
- Updated dependencies to latest versions

### Fixed
- Authentication token refresh logic
- Request timeout handling
- Error propagation in interceptors
- Cache key generation for complex requests
- GraphQL error handling

## [0.2.0] - 2025-04-10
### Added
- Initial GraphQL client implementation
- Basic caching support
- Authentication interceptors
- Error handling improvements

### Changed
- Restructured project for better organization
- Updated TypeScript configurations
- Improved documentation

### Fixed
- Request timeout issues
- Response parsing errors
- Authentication header formatting

## [0.1.0] - 2025-03-15
### Added
- Initial REST client implementation
- Basic authentication support
- Request/response interceptors
- Simple error handling
- TypeScript definitions for core API types