# Shared Retry Policy

_Added by Worker Γ – Error Recovery & Resilience_

`src/resilience/RetryPolicy.ts` provides a **single, opinionated retry helper** powered by the [`cockatiel`](https://github.com/connor4312/cockatiel) resilience library.

```ts
import [withRetry] from '@bluefly/bfapiclient/resilience';

const data = await withRetry(() => api.fetchStuff());
```

## Defaults

| Setting       | Value                  |
| ------------- | ---------------------- |
| Attempts      | 3 (total of 2 retries) |
| Strategy      | Exponential back-off   |
| Initial delay | 250 ms                 |
| Error filter  | `instanceof Error`     |

The policy is exported as:

```ts
export const defaultRetryPolicy: RetryPolicy;
export async function withRetry<T>(fn: () => Promise<T>): Promise<T>;
```

You can still create custom policies using Cockatiel, but using the shared helper ensures consistent telemetry and circuit-breaker integration.

## Telemetry Hooks

A placeholder `.beforeRetry()` callback is wired so we can emit events to Langfuse / Prometheus without changing every call-site later.

```ts
retry()
  .attempts(3)
  .beforeRetry(ctx => metrics.increment('retry', ctx.attempt));
```

## Unit Tests

See `__tests__/unit/retryPolicy.test.ts` – we simulate two failures and expect the promise to resolve on the third attempt.

```bash
npm run test -- retryPolicy
```

---

Maintainer: Worker Γ squad
