---
title: Package Information
description: NPM package details for llm-gateway
sidebar_position: 99
---

# Package Information

## Basic Info
- **Name**: `@bluefly/llm-gateway`
- **Version**: `0.1.6`
- **Description**: Production-ready LLM API gateway with intelligent routing, caching, and monitoring capabilities
- **License**: MIT
- **Repository**: [GitLab](https://gitlab.bluefly.io/llm/llm-gateway)

## Available Scripts
- **`npm run prepare`**: npm run build
- **`npm run clean`**: rimraf dist coverage
- **`npm run build`**: tsup
- **`npm run build:prod`**: NODE_ENV=production tsup --minify
- **`npm run build:watch`**: tsup --watch
- **`npm run dev`**: tsx src/minimal-server.ts
- **`npm run dev:debug`**: NODE_OPTIONS='--inspect' tsx src/minimal-server.ts
- **`npm run start`**: node dist/index.js
- **`npm run start:prod`**: NODE_ENV=production node dist/index.js
- **`npm run test`**: jest --passWithNoTests
- **`npm run test:watch`**: jest --watch
- **`npm run test:coverage`**: jest --coverage
- **`npm run test:ci`**: jest --passWithNoTests --ci --coverage --watchAll=false
- **`npm run lint`**: eslint 'src/**/*.{ts,js}' --config eslint.config.relaxed.js
- **`npm run lint:fix`**: eslint 'src/**/*.{ts,js}' --config eslint.config.relaxed.js --fix
- **`npm run format`**: prettier --write "src/**/*.{ts,js,json}"
- **`npm run format:check`**: prettier --check "src/**/*.{ts,js,json}"
- **`npm run typecheck`**: tsc --noEmit
- **`npm run tdd:red`**: npm run test:watch
- **`npm run tdd:green`**: npm run test
- **`npm run tdd:refactor`**: npm run test:coverage
- **`npm run tdd:validate`**: tddai tdd validate --coverage 95
- **`npm run generate:interfaces`**: openapi-typescript openapi.yaml -o src/types/api-interfaces.ts
- **`npm run openapi:validate`**: swagger-cli validate openapi.yaml
- **`npm run ci`**: npm run clean && npm run test:ci && npm run build:prod
- **`npm run prepublishOnly`**: npm run clean && npm run build:prod
- **`npm run publish:npm`**: npm publish --access public
- **`npm run audit`**: npm audit --audit-level=moderate
- **`npm run audit:fix`**: npm audit fix
- **`npm run docker:build`**: docker build -t registry.gitlab.bluefly.io/llm/llm-gateway:latest .
- **`npm run docker:push`**: docker push registry.gitlab.bluefly.io/llm/llm-gateway:latest
- **`npm run katenary:convert`**: katenary convert -f deployment/katenary/docker-compose.katenary.yml -o deployment/helm-charts/llm-gateway
- **`npm run katenary:deploy`**: katenary deploy -f deployment/katenary/docker-compose.katenary.yml
- **`npm run k8s:generate`**: npm run docker:build && npm run katenary:convert
- **`npm run k8s:deploy`**: npm run docker:push && npm run katenary:deploy
- **`npm run deploy:staging`**: npm run k8s:generate && kubectl apply -f deployment/helm-charts/llm-gateway --namespace=llm-staging
- **`npm run deploy:production`**: npm run k8s:generate && kubectl apply -f deployment/helm-charts/llm-gateway --namespace=llm-production

## Dependencies (63)
- @anthropic-ai/sdk
- @apollo/server
- @graphql-tools/schema
- @keyv/redis
- @langchain/anthropic
- @langchain/core
- @langchain/openai
- @opentelemetry/api
- @opentelemetry/auto-instrumentations-node
- @opentelemetry/exporter-metrics-otlp-http
- @opentelemetry/exporter-trace-otlp-http
- @opentelemetry/resources
- @opentelemetry/sdk-metrics
- @opentelemetry/sdk-node
- @opentelemetry/sdk-trace-base
- @opentelemetry/sdk-trace-node
- @opentelemetry/semantic-conventions
- @pinecone-database/pinecone
- axios
- axios-retry
- bcryptjs
- bullmq
- chalk
- compression
- cors
- dataloader
- dotenv
- express
- express-jwt
- express-openapi-validator
- express-rate-limit
- glob
- graphql
- graphql-depth-limit
- graphql-query-complexity
- graphql-subscriptions
- helmet
- http-errors
- http-proxy-middleware
- ioredis
- joi
- js-yaml
- json-rpc-2.0
- jsonwebtoken
- keyv
- knex
- langchain
- morgan
- mysql2
- node-cache
- openai
- path-exists
- pg
- pino-pretty
- prom-client
- rate-limiter-flexible
- swagger-ui-dist
- swagger-ui-express
- uuid
- winston
- winston-daily-rotate-file
- zod
- zod-to-openapi

## Dev Dependencies (44)
- @babel/preset-env
- @babel/preset-typescript
- @jest/globals
- @openapitools/openapi-generator-cli
- @semantic-release/changelog
- @semantic-release/commit-analyzer
- @semantic-release/git
- @semantic-release/npm
- @semantic-release/release-notes-generator
- @types/bcryptjs

... and 34 more
