# AI Coding Assistant

The LLM PlatformAI Coding Assistant integrates the best features from Cursor IDE and Claude Code into a unified coding assistant that leverages both llm-mcp and native_aijs components.

## Overview

The AI Coding Assistant combines neural fabric capabilities with MCP-based tool orchestration to provide a comprehensive solution for code generation, editing, analysis, and visualization. It uses neurosymbolic reasoning to understand code patterns and architectural relationships while providing natural language interactions for common development tasks.

## Core Components

- **MCP-based Coding Assistant**: Orchestrates tools, manages tasks, and provides git integration
- **Neural Fabric Coding Assistant**: Handles pattern recognition, code understanding, and visualization
- **Configuration System**: JSON-based configuration for feature customization

## Features

- **Codebase Understanding**: Semantic search and intelligent code analysis
- **Smart Editing**: Context-aware code edits with semantic preservation
- **Visualization**: Architecture and dependency visualization
- **Natural Language**: Command processing for common development tasks
- **Git Operations**: Natural language git commands and PR workflows
- **Task Planning**: Breaking complex tasks into executable steps

## Architecture

![Architecture Diagram](./architecture-diagram.svg)

The implementation follows a hybrid approach where:

1. llm-mcp handles orchestration, tool management, and git operations
2. native_aijs provides neural fabric capabilities, pattern recognition, and neurosymbolic reasoning
3. Both systems communicate via well-defined interfaces

## Getting Started

See the [Installation Guide](./installation.md) and [Usage Guide](./usage.md) for setup instructions and examples.

## API Reference

The [API Reference](./api-reference.md) provides detailed documentation for all available methods and interfaces.

## Examples

Check the [Examples](./examples.md) page for common usage patterns and code snippets.

## Integration

The [Integration Guide](./integration.md) explains how to integrate the AI Coding Assistant with existing tools and workflows.

## Comparison with Existing Tools

| Feature | Cursor IDE | Claude Code | LLM PlatformAI Coding Assistant |
|---------|------------|------------|----------------------------|
| Codebase Understanding |  |  |  |
| Multi-file Editing |  |  Limited |  |
| Git Operations |  Basic |  |  |
| Terminal Integration | ❌ |  |  |
| Natural Language |  |  |  |
| Visualization |  Basic | ❌ |  |
| Pattern Recognition |  |  Limited |  |
| Neurosymbolic Reasoning | ❌ |  Limited |  |
| Enterprise Integration |  Limited |  |  |