# Setup Guide

> Note: This document replaces a symlink that previously pointed to `./llm-mcp/docs/guides/setup.md` which doesn't exist.

This guide covers the setup and installation process for the Model Control Plane.

## Prerequisites

- Node.js 18.x or higher
- npm 9.x or higher
- Access to AI provider API keys

## Installation

Install the MCP package:

```bash
npm install @bluefly/mcp
```

## Configuration

Create a configuration file (e.g., `mcp-config.js`):

```javascript
module.exports = {
  api: {
    port: 3000,
    host: 'localhost'
  },
  providers: {
    anthropic: {
      apiKey: process.env.ANTHROPIC_API_KEY,
      defaultModel: 'claude-3-sonnet'
    },
    openai: {
      apiKey: process.env.OPENAI_API_KEY,
      defaultModel: 'gpt-4'
    }
  },
  cache: {
    enabled: true,
    ttl: 3600 // seconds
  },
  logging: {
    level: 'info',
    format: 'json'
  }
};
```

## Running the Service

```bash
npx mcp-server --config mcp-config.js
```

## Environment Variables

For secure deployment, use environment variables:

```bash
# Required
export MCP_ANTHROPIC_API_KEY="your_api_key"
export MCP_OPENAI_API_KEY="your_api_key"

# Optional
export MCP_PORT=3000
export MCP_HOST="0.0.0.0"
export MCP_LOG_LEVEL="info"
```

## Docker Deployment

```bash
docker run -p 3000:3000 \
  -e MCP_ANTHROPIC_API_KEY="your_api_key" \
  -e MCP_OPENAI_API_KEY="your_api_key" \
  bluefly/mcp:latest
```

For more advanced setup options, see the detailed configuration guide.