# Reference Title

Brief overview of this reference documentation. Explain what this reference covers and how it can be used. This section should be 1-2 paragraphs that give context to the reference material.

## Table of Contents

- [Overview](#overview)
- [Reference Section 1](#reference-section-1)
- [Reference Section 2](#reference-section-2)
- [Data Types](#data-types)
- [Examples](#examples)
- [See Also](#see-also)

## Overview

Detailed overview of the reference material. This section should provide a high-level understanding of the component, API, or system being documented. Include architectural diagrams if applicable.

```mermaid
graph TD;
  A[Component A] --> B[Component B];
  A --> C[Component C];
  B --> D[Component D];
  C --> D;
```

## Reference Section 1

Detailed reference for the first section. Use tables, lists, and code examples to clearly document the API, configuration options, or other reference material.

### Subsection 1.1

Specific details about a particular aspect of the section.

```typescript
// Code example illustrating usage
const config = {
  option1: 'value1',
  option2: 42,
  option3: {
    nestedOption: true
  }
};
```

### Subsection 1.2

More specific details with examples.

| Property | Type | Required | Description |
|----------|------|----------|-------------|
| `property1` | string | Yes | Description of property1 |
| `property2` | number | No | Description of property2 |
| `property3` | object | No | Description of property3 |

## Reference Section 2

Detailed reference for the second section.

### Subsection 2.1

Specific details about a particular aspect of the section.

> **Note:** Include important notes, warnings, or tips in blockquotes.

### Subsection 2.2

More specific details with examples.

## Data Types

Document the data types used in the API or configuration.

### Type 1

```typescript
interface Type1 {
  field1: string;
  field2: number;
  field3?: boolean; // Optional
}
```

Description of Type1 and its fields.

### Type 2

```typescript
interface Type2 {
  fieldA: string;
  fieldB: Type1[]; // Array of Type1
}
```

Description of Type2 and its fields.

## Examples

Provide practical examples of using the reference material.

### Example 1: Basic Usage

This example demonstrates basic usage of the reference material.

```typescript
import [SomeAPI] from '@llm-mcp/module';

// Example code using the reference material
const api = new SomeAPI({
  config: {
    option1: 'value1'
  }
});

const result = api.someMethod('input');
console.log(result);
```

### Example 2: Advanced Usage

This example demonstrates more advanced usage.

```typescript
// Advanced example code
```

## See Also

- [Related Reference 1](path/to/related-reference-1.md) - Brief description of related reference
- [Related Reference 2](path/to/related-reference-2.md) - Brief description of related reference
- [Guide](path/to/guide.md) - Guide that explains how to use this reference material