# Legacy Files to Migrate

This document lists files that should be migrated, removed, or replaced as part of the ongoing BFUI modernization effort.

## SCSS Files to Remove

These SCSS files should be removed as their components have been migrated to Chakra UI or Tailwind CSS:

- [x] `/src/components/Card/Card.scss`: Replaced by Chakra UI styling in Card.tsx and Tailwind CSS in TailwindCard.tsx

## JavaScript Files to Convert to TypeScript

These JavaScript files should be converted to TypeScript for better type safety and consistency:

- [ ] `/src/components/common/Modal.js`: Convert to TypeScript (Modal.tsx)
- [ ] `/src/components/dashboard/Dashboard.js`: Convert to TypeScript (Dashboard.tsx)
- [ ] `/src/components/dashboard/DashboardGrid.js`: Convert to TypeScript (DashboardGrid.tsx)
- [ ] `/src/components/dashboard/DashboardWidget.js`: Convert to TypeScript (DashboardWidget.tsx)
- [ ] `/src/components/data/Pagination.js`: Convert to TypeScript (Pagination.tsx)
- [ ] `/src/components/data/Table.js`: Convert to TypeScript (Table.tsx)
- [ ] `/src/components/forms/Button.js`: Convert to TypeScript (Button.tsx)
- [ ] `/src/components/forms/Checkbox.js`: Convert to TypeScript (Checkbox.tsx)
- [ ] `/src/components/forms/Input.js`: Convert to TypeScript (Input.tsx)
- [ ] `/src/components/forms/Radio.js`: Convert to TypeScript (Radio.tsx)
- [ ] `/src/components/forms/Select.js`: Convert to TypeScript (Select.tsx)
- [ ] `/src/components/forms/Textarea.js`: Convert to TypeScript (Textarea.tsx)
- [ ] `/src/components/navigation/Accordion.js`: Convert to TypeScript (Accordion.tsx)
- [ ] `/src/components/navigation/Breadcrumbs.js`: Convert to TypeScript (Breadcrumbs.tsx)
- [ ] `/src/components/navigation/Tabs.js`: Convert to TypeScript (Tabs.tsx)
- [ ] `/src/hooks/useDashboardData.js`: Convert to TypeScript (useDashboardData.ts)
- [ ] `/src/hooks/useDashboardState.js`: Convert to TypeScript (useDashboardState.ts)
- [ ] `/src/pages/DashboardPage.js`: Convert to TypeScript (DashboardPage.tsx)

## Components to Migrate to Tailwind CSS

These components should have Tailwind CSS alternatives created:

- [x] Button: Created TailwindButton component
- [x] Card: Created TailwindCard component
- [ ] Input: Create TailwindInput component
- [ ] Select: Create TailwindSelect component
- [ ] Checkbox: Create TailwindCheckbox component
- [ ] RadioGroup: Create TailwindRadioGroup component
- [ ] Modal: Create TailwindModal component
- [ ] Alert: Create TailwindAlert component
- [ ] Toast: Create TailwindToast component
- [ ] Tabs: Create TailwindTabs component
- [ ] Form components: Create TailwindForm component family

## Migration Priority

1. High Priority:
   - Core UI components (Button, Card, Input, Form elements)
   - Components used in critical user flows

2. Medium Priority:
   - Navigation components
   - Layout components
   - Feedback components

3. Lower Priority:
   - Specialized components
   - Rarely used components

## Migration Process

For each file:

1. Create TypeScript interfaces for props and state
2. Convert component to TypeScript
3. Add proper typing for all functions and variables
4. Improve component with modern React patterns
5. Write comprehensive tests
6. Update documentation

## Completion Checklist

- [ ] All SCSS files removed or replaced
- [ ] All JavaScript files converted to TypeScript
- [ ] Tailwind CSS alternatives created for all components
- [ ] Tests updated for all components
- [ ] Documentation updated for all components