# CI Troubleshooting Guide

This guide helps resolve common issues with the GitLab CI pipeline for BFRFP.

## Common Issues

### ESLint Errors

ESLint errors typically occur due to code style violations:

````text
error  'someVar' is assigned a value but never used  no - unused - vars
```text

#### Solution

Run ESLint locally to identify and fix issues:

```bash
npm run lint
```text

Or to automatically fix issues:

```bash
npm run lint -- --fix
```text

### TypeScript Errors

TypeScript errors occur when types don't match or imports are incorrect:

```text
TS2307: Cannot find module '. / some - module' or its corresponding type declarations.
```text

#### Solution

Verify your imports and run TypeScript check locally:

```bash
npm run typecheck
```text

### Build Failures

Build failures often occur due to TypeScript errors or module format issues.

#### Solution

Check your tsconfig.json configuration and ensure it's set up for ES modules:

```json
{
  "compilerOptions": {
    "module": "esnext",
    "moduleResolution": "node",
    "esModuleInterop": true
  }
}
```text

### Test Failures

Test failures indicate that some tests are not passing.

#### Solution

Run tests locally to identify the failing tests:

```bash
npm test
```text

### Documentation Issues

Documentation jobs might fail if required documentation files are missing.

#### Solution

Ensure the documentation structure is correct:
- docs / index.md
- docs / api / API.md
- Other required documentation files

## Testing CI Locally

Use the included script to test CI locally before pushing:

```bash
. / scripts / test - ci - locally.sh
```text

Or to automatically fix issues:

```bash
. / scripts / test - ci - locally.sh --fix
```text

## Advanced CI Configuration

The CI pipeline is configured in .gitlab - ci.yml and uses shared configuration from the BFCommon repository.

### Variables

Modify CI variables in .gitlab - ci.yml:

```yaml
variables:

# Project - specific variables
  PROJ_NAME: "bfrfp"
  NODE_VERSION: "20"

# ...
```text

### Debugging

For detailed CI debugging, set the CI_DEBUG_TRACE variable:

```yaml
variables:
  CI_DEBUG_TRACE: "true"
```text
````
