# Secure Drupal Module File Mapping

This document provides a detailed mapping of files from the current module structure to the new restructured module organization. This will serve as a reference during the implementation process.

## 1. Secure Compliance Suite

### Source Modules:
- secure_compliance
- secure_compliance_profile
- secure_ai_compliance
- secure_pci
- secure_fedramp
- unified_compliance_security
- compliance_framework

### File Mapping:

#### Core Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_compliance/secure_compliance.info.yml | modules/secure_compliance_suite/secure_compliance_suite.info.yml |
| modules/secure_compliance/secure_compliance.module | modules/secure_compliance_suite/secure_compliance_suite.module |
| modules/secure_compliance/secure_compliance.routing.yml | modules/secure_compliance_suite/secure_compliance_suite.routing.yml |
| modules/secure_compliance/secure_compliance.services.yml | modules/secure_compliance_suite/secure_compliance_suite.services.yml |
| modules/secure_compliance/secure_compliance.permissions.yml | modules/secure_compliance_suite/secure_compliance_suite.permissions.yml |

#### Service Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_compliance/src/Service/*.php | modules/secure_compliance_suite/src/Service/ |
| modules/secure_fedramp/src/Service/*.php | modules/secure_compliance_suite/src/Service/Regime/Fedramp/ |
| modules/secure_pci/src/Service/*.php | modules/secure_compliance_suite/src/Service/Regime/Pci/ |
| modules/secure_ai_compliance/src/Service/*.php | modules/secure_compliance_suite/src/Service/AI/ |
| modules/compliance_framework/src/Service/*.php | modules/secure_compliance_suite/src/Service/Framework/ |

#### Controller Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_compliance/src/Controller/*.php | modules/secure_compliance_suite/src/Controller/ |
| modules/secure_fedramp/src/Controller/*.php | modules/secure_compliance_suite/src/Controller/Regime/Fedramp/ |
| modules/secure_pci/src/Controller/*.php | modules/secure_compliance_suite/src/Controller/Regime/Pci/ |
| modules/unified_compliance_security/src/Controller/*.php | modules/secure_compliance_suite/src/Controller/Unified/ |

#### Plugin Files:

| Source File | Destination File |
|-------------|------------------|
| modules/compliance_framework/src/Plugin/CompliancePlugin/*.php | modules/secure_compliance_suite/src/Plugin/ComplianceFramework/ |
| modules/compliance_framework/src/Annotation/CompliancePlugin.php | modules/secure_compliance_suite/src/Annotation/ComplianceFramework.php |

#### Templates:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_compliance/templates/*.html.twig | modules/secure_compliance_suite/templates/ |
| modules/secure_fedramp/templates/*.html.twig | modules/secure_compliance_suite/templates/regime/fedramp/ |
| modules/secure_pci/templates/*.html.twig | modules/secure_compliance_suite/templates/regime/pci/ |
| modules/unified_compliance_security/templates/*.html.twig | modules/secure_compliance_suite/templates/unified/ |

#### CSS/JS:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_compliance/css/*.css | modules/secure_compliance_suite/css/ |
| modules/secure_compliance/js/*.js | modules/secure_compliance_suite/js/ |
| modules/secure_fedramp/css/*.css | modules/secure_compliance_suite/css/regime/fedramp/ |
| modules/secure_fedramp/js/*.js | modules/secure_compliance_suite/js/regime/fedramp/ |
| modules/secure_pci/css/*.css | modules/secure_compliance_suite/css/regime/pci/ |
| modules/secure_pci/js/*.js | modules/secure_compliance_suite/js/regime/pci/ |
| modules/unified_compliance_security/css/*.css | modules/secure_compliance_suite/css/unified/ |
| modules/unified_compliance_security/js/*.js | modules/secure_compliance_suite/js/unified/ |

#### Configuration:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_compliance/config/install/*.yml | modules/secure_compliance_suite/config/install/ |
| modules/secure_fedramp/config/install/*.yml | modules/secure_compliance_suite/config/install/regime/fedramp/ |
| modules/secure_pci/config/install/*.yml | modules/secure_compliance_suite/config/install/regime/pci/ |
| modules/compliance_framework/config/install/*.yml | modules/secure_compliance_suite/config/install/framework/ |

## 2. Secure Evidence

### Source Modules:
- secure_evidence_log
- secure_evidence_dblog
- secure_evidence_config
- release_evidence

### File Mapping:

#### Core Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_evidence_log/secure_evidence_log.info.yml | modules/secure_evidence/secure_evidence.info.yml |
| modules/secure_evidence_log/secure_evidence_log.module | modules/secure_evidence/secure_evidence.module |
| modules/secure_evidence_log/secure_evidence_log.routing.yml | modules/secure_evidence/secure_evidence.routing.yml |
| modules/secure_evidence_log/secure_evidence_log.services.yml | modules/secure_evidence/secure_evidence.services.yml |
| modules/secure_evidence_log/secure_evidence_log.permissions.yml | modules/secure_evidence/secure_evidence.permissions.yml |

#### Service Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_evidence_log/src/Service/*.php | modules/secure_evidence/src/Service/ |
| modules/secure_evidence_dblog/src/Service/*.php | modules/secure_evidence/src/Service/Storage/ |
| modules/secure_evidence_config/src/Service/*.php | modules/secure_evidence/src/Service/Provider/ |
| modules/release_evidence/src/Service/*.php | modules/secure_evidence/src/Service/Release/ |

#### Plugin Files:

| Source File | Destination File |
|-------------|------------------|
| src/Plugin/EvidenceProvider/*.php | modules/secure_evidence/src/Plugin/EvidenceProvider/ |
| src/Annotation/EvidenceProvider.php | modules/secure_evidence/src/Annotation/EvidenceProvider.php |

## 3. Secure Audit Tools

### Source Modules:
- secure_task_tracker
- secure_audit
- secure_drupal_healing_logging

### File Mapping:

#### Core Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_audit/secure_audit.info.yml | modules/secure_audit_tools/secure_audit_tools.info.yml |
| modules/secure_audit/secure_audit.module | modules/secure_audit_tools/secure_audit_tools.module |
| modules/secure_audit/secure_audit.routing.yml | modules/secure_audit_tools/secure_audit_tools.routing.yml |
| modules/secure_audit/secure_audit.services.yml | modules/secure_audit_tools/secure_audit_tools.services.yml |
| modules/secure_audit/secure_audit.permissions.yml | modules/secure_audit_tools/secure_audit_tools.permissions.yml |

#### Service Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_audit/src/Service/*.php | modules/secure_audit_tools/src/Service/ |
| modules/secure_task_tracker/src/Service/*.php | modules/secure_audit_tools/src/Service/TaskTracker/ |
| modules/secure_drupal_healing_logging/src/Service/*.php | modules/secure_audit_tools/src/Service/Healing/ |

#### Controller Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_audit/src/Controller/*.php | modules/secure_audit_tools/src/Controller/ |
| modules/secure_task_tracker/src/Controller/*.php | modules/secure_audit_tools/src/Controller/TaskTracker/ |

#### Templates:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_task_tracker/templates/*.html.twig | modules/secure_audit_tools/templates/task/ |
| modules/secure_audit/templates/*.html.twig | modules/secure_audit_tools/templates/ |

#### CSS/JS:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_task_tracker/css/*.css | modules/secure_audit_tools/css/task/ |
| modules/secure_task_tracker/js/*.js | modules/secure_audit_tools/js/task/ |
| modules/secure_audit/css/*.css | modules/secure_audit_tools/css/ |
| modules/secure_audit/js/*.js | modules/secure_audit_tools/js/ |

## 4. Secure Hardening

### Source Modules:
- secure_headers
- secure_controls
- secure_config
- secure_core
- theme_security

### File Mapping:

#### Core Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_controls/secure_controls.info.yml | modules/secure_hardening/secure_hardening.info.yml |
| modules/secure_controls/secure_controls.module | modules/secure_hardening/secure_hardening.module |
| modules/secure_controls/secure_controls.routing.yml | modules/secure_hardening/secure_hardening.routing.yml |
| modules/secure_controls/secure_controls.services.yml | modules/secure_hardening/secure_hardening.services.yml |
| modules/secure_controls/secure_controls.permissions.yml | modules/secure_hardening/secure_hardening.permissions.yml |

#### Submodule Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_headers/**/* | modules/secure_hardening/modules/secure_headers/ |
| modules/secure_config/**/* | modules/secure_hardening/modules/secure_config/ |
| modules/secure_core/**/* | modules/secure_hardening/modules/secure_core/ |
| modules/theme_security/**/* | modules/secure_hardening/modules/theme_security/ |

#### Service Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_controls/src/Service/*.php | modules/secure_hardening/src/Service/ |

#### Plugin Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_controls/src/Plugin/SecurityControl/*.php | modules/secure_hardening/src/Plugin/SecurityControl/ |
| modules/secure_controls/src/Annotation/SecurityControl.php | modules/secure_hardening/src/Annotation/SecurityControl.php |

## 5. Secure Auth

### Source Modules:
- secure_auth
- authentication
- password-policy

### File Mapping:

#### Core Files:

| Source File | Destination File |
|-------------|------------------|
| modules/secure_auth/secure_auth.info.yml | modules/secure_auth/secure_auth.info.yml (update) |
| modules/secure_auth/secure_auth.module | modules/secure_auth/secure_auth.module (update) |
| modules/secure_auth/secure_auth.routing.yml | modules/secure_auth/secure_auth.routing.yml (update) |
| modules/secure_auth/secure_auth.services.yml | modules/secure_auth/secure_auth.services.yml (update) |

#### Submodule Files:

| Source File | Destination File |
|-------------|------------------|
| modules/authentication/**/* | modules/secure_auth/src/Authentication/ |
| modules/password-policy/**/* | modules/secure_auth/modules/password_policy/ |

## 6. Module Renamings

### 6.1. Secure Policy Bridge

| Source File | Destination File |
|-------------|------------------|
| modules/policy_bridge/**/* | modules/secure_policy_bridge/ |

### 6.2. Secure Separation of Duties (SOD)

| Source File | Destination File |
|-------------|------------------|
| modules/separation_of_duties/**/* | modules/secure_sod/ |

### 6.3. Secure OpenAPI Enforcer

| Source File | Destination File |
|-------------|------------------|
| modules/openapi_compliance_enforcer/**/* | modules/secure_openapi_enforcer/ |

## 7. Resource Reorganization

| Source File | Destination File |
|-------------|------------------|
| modules/resources/**/* | resources/ |

## 8. Keep Separate

The following modules will remain separate and should be updated to work with the new structure:

- secure_eca
- secure_accessibility

## Notes on File Movement:

1. When moving files, update the namespace declarations in PHP files
2. Update service names and references in YAML files
3. Update route names and paths in routing YAML files
4. Update template references in theme hooks
5. Update library references for CSS and JS files

## Class Namespace Updates:

For each moved file, update the namespace according to this pattern:

| Original Namespace | New Namespace |
|-------------------|---------------|
| Drupal\secure_compliance | Drupal\secure_compliance_suite |
| Drupal\secure_compliance_profile | Drupal\secure_compliance_suite\Profile |
| Drupal\secure_evidence_log | Drupal\secure_evidence |
| Drupal\secure_evidence_dblog | Drupal\secure_evidence\Dblog |
| Drupal\secure_audit | Drupal\secure_audit_tools |
| Drupal\secure_task_tracker | Drupal\secure_audit_tools\TaskTracker |
| Drupal\secure_controls | Drupal\secure_hardening |
| Drupal\secure_headers | Drupal\secure_hardening\Headers |
| Drupal\policy_bridge | Drupal\secure_policy_bridge |
| Drupal\separation_of_duties | Drupal\secure_sod |
| Drupal\openapi_compliance_enforcer | Drupal\secure_openapi_enforcer |

## Service Name Updates:

Update service names in services.yml files and service references throughout the codebase:

| Original Service Name | New Service Name |
|----------------------|-----------------|
| secure_compliance.manager | secure_compliance_suite.manager |
| secure_evidence_log.provider | secure_evidence.provider |
| secure_audit.manager | secure_audit_tools.manager |
| secure_task_tracker.service | secure_audit_tools.task_tracker |
| secure_controls.manager | secure_hardening.manager |
| policy_bridge.service | secure_policy_bridge.service |
| separation_of_duties.manager | secure_sod.manager |
| openapi_compliance_enforcer.validator | secure_openapi_enforcer.validator |

## Module Dependency Updates:

Update module dependencies in info.yml files:

| Original Dependency | New Dependency |
|---------------------|----------------|
| secure_compliance | secure_compliance_suite |
| secure_compliance_profile | secure_compliance_suite |
| secure_evidence_log | secure_evidence |
| secure_evidence_dblog | secure_evidence |
| secure_audit | secure_audit_tools |
| secure_task_tracker | secure_audit_tools |
| secure_controls | secure_hardening |
| secure_headers | secure_hardening:secure_headers |
| policy_bridge | secure_policy_bridge |
| separation_of_duties | secure_sod |
| openapi_compliance_enforcer | secure_openapi_enforcer |