# Secure Drupal Recipe

A Drupal recipe that installs common security-related modules.

## What this recipe provides:

### Security Modules
This recipe installs several contrib security modules:
- **security_review**: Security scanning and recommendations
- **password_policy**: Password strength requirements
- **autologout**: Automatic session timeout
- **tfa**: Two-factor authentication support
- **login_security**: Brute force protection
- **seckit**: Security headers configuration

### Additional Security Features
- **captcha**: CAPTCHA for forms
- **honeypot**: Spam protection
- **shield**: HTTP authentication option
- **admin_audit_trail**: Audit logging

### Privacy/Compliance Modules
- **gdpr**: GDPR compliance tools
- **eu_cookie_compliance**: Cookie consent
- **encrypt**: Field encryption
- **key**: Key management

## Installation

```bash
# Apply the recipe to a new site
drush recipe:apply secure_drupal

# Or apply to existing site
drush recipe:apply secure_drupal --include-existing-config
```

## Post-Installation

After applying the recipe:

1. Configure security modules in Configuration > Security
2. Set up password policies
3. Configure two-factor authentication
4. Review security settings with `drush secrev`
5. Configure session timeout settings
6. Set up audit logging

## Security Checklist

- [ ] Configure password policy requirements
- [ ] Enable two-factor authentication for admin users
- [ ] Set appropriate session timeout
- [ ] Run security review (`drush secrev`)
- [ ] Configure login attempt limits
- [ ] Enable HTTPS
- [ ] Configure security headers
- [ ] Set up regular security updates

## Notes

- This recipe installs multiple contrib modules that may have overlapping functionality
- Review each module's configuration to avoid conflicts
- Some modules may require additional configuration to be effective
- Not all modules may be necessary for every site - disable unused modules
- Always test security configurations in a development environment first

## Maintenance

Regular maintenance tasks:
- Check for security updates: `composer outdated "drupal/*"`
- Review security settings: `drush secrev`
- Monitor audit logs if enabled
- Review user permissions regularly

## License

GPL-2.0+