// Nightwatch E2E: Secure Drupal Password Policy Enforcement

module.exports = {
  '@tags': ['secure_drupal', 'password_policy', 'security'],

  'Enforce and Test Password Policy for User Accounts': function (browser) {
    // 1. Log in as admin
    browser
      .drupalLogin({username: 'admin', password: 'admin'});

    // 2. Visit Password Policy configuration page
    browser
      .url(browser.launchUrl + '/admin/config/people/password_policy')
      .waitForElementVisible('form', 2000)
      .assert.containsText('body', 'Password Policy')
      .setValue('input[name="min_length"]', '12')
      .setValue('input[name="require_numbers"]', true)
      .setValue('input[name="require_uppercase"]', true)
      .setValue('input[name="require_special"]', true)
      .click('input#edit-submit')
      .waitForElementVisible('.messages--status', 2000)
      .assert.containsText('.messages--status', 'The configuration options have been saved');

    // 3. Attempt to create a user with a weak password
    browser
      .url(browser.launchUrl + '/admin/people/create')
      .setValue('input[name="name"]', 'testuser')
      .setValue('input[name="mail"]', 'testuser@example.com')
      .setValue('input[name="pass[pass1]"]', 'weakpass')
      .setValue('input[name="pass[pass2]"]', 'weakpass')
      .click('input#edit-submit')
      .waitForElementVisible('.messages--error', 2000)
      .assert.containsText('.messages--error', 'Password does not meet the policy requirements');

    // 4. Create a user with a strong password
    browser
      .setValue('input[name="pass[pass1]"]', 'StrongPass123!')
      .setValue('input[name="pass[pass2]"]', 'StrongPass123!')
      .click('input#edit-submit')
      .waitForElementVisible('.messages--status', 2000)
      .assert.containsText('.messages--status', 'Created a new user account for testuser');

    browser.end();
  }
};