// Nightwatch E2E: Secure Drupal Permissions and Access Control

module.exports = {
  '@tags': ['secure_drupal', 'permissions', 'access_control'],

  'Verify Permissions and Access Control for Security Features': function (browser) {
    // 1. Log in as admin and verify access to security config
    browser
      .drupalLogin({username: 'admin', password: 'admin'})
      .url(browser.launchUrl + '/admin/config/people/tfa')
      .waitForElementVisible('body', 2000)
      .assert.containsText('body', 'Two-factor Authentication')
      .url(browser.launchUrl + '/admin/reports/security-review')
      .waitForElementVisible('body', 2000)
      .assert.containsText('body', 'Security Review');

    // 2. Log out and log in as a non-privileged user
    browser
      .url(browser.launchUrl + '/user/logout')
      .url(browser.launchUrl + '/user/login')
      .setValue('input[name="name"]', 'testuser')
      .setValue('input[name="pass"]', 'StrongPass123!')
      .click('input#edit-submit')
      .waitForElementVisible('body', 2000);

    // 3. Attempt to access security config and reports as non-privileged user
    browser
      .url(browser.launchUrl + '/admin/config/people/tfa')
      .waitForElementVisible('body', 2000)
      .assert.containsText('body', 'Access denied')
      .url(browser.launchUrl + '/admin/reports/security-review')
      .waitForElementVisible('body', 2000)
      .assert.containsText('body', 'Access denied');

    browser.end();
  }
};