// Nightwatch E2E: Secure Drupal Security Dashboard and Compliance

module.exports = {
  '@tags': ['secure_drupal', 'security', 'compliance'],

  'Verify Security Dashboard and Compliance Status': function (browser) {
    // 1. Log in as admin
    browser
      .drupalLogin({username: 'admin', password: 'admin'});

    // 2. Visit Security Review dashboard
    browser
      .url(browser.launchUrl + '/admin/reports/security-review')
      .waitForElementVisible('body', 2000)
      .assert.containsText('body', 'Security Review')
      .assert.containsText('body', 'No critical issues')
      .assert.containsText('body', '2FA')
      .assert.containsText('body', 'Password Policy')
      .assert.containsText('body', 'Auto-logout')
      .assert.containsText('body', 'Security Headers');

    // 3. Visit Compliance Report page
    browser
      .url(browser.launchUrl + '/admin/reports/compliance')
      .waitForElementVisible('body', 2000)
      .assert.containsText('body', 'Compliance Report')
      .assert.containsText('body', 'FedRAMP')
      .assert.containsText('body', 'HIPAA')
      .assert.containsText('body', 'SOC 2')
      .assert.containsText('body', 'NIST 800-53');

    // 4. Optionally, check for AI features toggle (if present)
    browser
      .url(browser.launchUrl + '/admin/config/secure_drupal/ai')
      .waitForElementVisible('form', 2000)
      .assert.containsText('body', 'AI Features')
      .click('input#edit-enable-ai')
      .waitForElementVisible('.messages--status', 2000)
      .assert.containsText('.messages--status', 'AI features enabled');

    browser.end();
  }
};