// Nightwatch E2E: Secure Drupal Two-Factor Authentication Enforcement

module.exports = {
  '@tags': ['secure_drupal', '2fa', 'security'],

  'Enforce and Test Two-Factor Authentication for Admin': function (browser) {
    // 1. Log in as admin
    browser
      .drupalLogin({username: 'admin', password: 'admin'});

    // 2. Visit TFA configuration page
    browser
      .url(browser.launchUrl + '/admin/config/people/tfa')
      .waitForElementVisible('form', 2000)
      .assert.containsText('body', 'Two-factor Authentication')
      .setValue('input[name="tfa_enabled"]', true)
      .click('input#edit-submit')
      .waitForElementVisible('.messages--status', 2000)
      .assert.containsText('.messages--status', 'The configuration options have been saved');

    // 3. Log out and attempt to log in again
    browser
      .url(browser.launchUrl + '/user/logout')
      .url(browser.launchUrl + '/user/login')
      .setValue('input[name="name"]', 'admin')
      .setValue('input[name="pass"]', 'admin')
      .click('input#edit-submit')
      .waitForElementVisible('form#tfa-login-form', 2000)
      .assert.containsText('body', 'Enter your authentication code');

    browser.end();
  }
};