# Migration Guide for ReelCode

This document guides users of CodeOwl and AI Coding Assistant on transitioning to ReelCode, which merges the functionality of both tools.

## Table of Contents

1. [Introduction](#introduction)
2. [Installation](#installation)
3. [Command Migration](#command-migration)
4. [Configuration Migration](#configuration-migration)
5. [API Migration](#api-migration)
6. [CI/CD Integration Migration](#cicd-integration-migration)
7. [FAQ](#faq)

## Introduction

ReelCode is a comprehensive AI coding assistant that combines:

- Code quality analysis from AI Coding Assistant
- Code ownership intelligence from CodeOwl

This merged project provides a unified platform with enhanced features and a streamlined developer experience.

## Installation

### From CodeOwl

```bash
# Previous CodeOwl installation
npm uninstall -g @bluefly/codeowl

# New ReelCode installation
npm install -g @bluefly/tddai
```

### From AI Coding Assistant

```bash
# Previous AI Coding Assistant installation
npm uninstall -g @bluefly/ai-coding-assistant

# New ReelCode installation
npm install -g @bluefly/tddai
```

## Command Migration

### CodeOwl Users

| Previous Command (CodeOwl) | New Command (ReelCode) |
|---------------------------|------------------------|
| `codeowl analyze <path>` | `tddai ownership:analyze <path>` |
| `codeowl optimize <path>` | `tddai ownership:optimize <path>` |
| `codeowl validate <path>` | `tddai ownership:validate <path>` |
| `codeowl report <path>` | `tddai ownership:report <path>` |
| `codeowl silos <path>` | `tddai silos:detect <path>` |
| `codeowl-federated federated-analyze <path>` | `tddai federated:analyze <path>` |
| `codeowl-federated silos-emergence <path>` | `tddai silos:emergence <path>` |
| `codeowl-federated blockchain-store <path>` | `tddai federated:blockchain-store <path>` |

### AI Coding Assistant Users

| Previous Command (AI Coding Assistant) | New Command (ReelCode) |
|---------------------------------------|------------------------|
| `llmcli analyze <path>` | `tddai analyze <path>` |
| `llmcli test:generate <path>` | `tddai test:generate <path>` |
| `llmcli validate <path>` | `tddai validate <path>` |
| `llmcli metrics <path>` | `tddai metrics <path>` |
| `llmcli config:show` | `tddai config:show` |
| `llmcli config:set <key> <value>` | `tddai config:set <key> <value>` |
| `llmcli project:init` | `tddai project:init` |
| `llmcli project:status` | `tddai project:status` |

## Configuration Migration

### From CodeOwl

1. If you have a `.codeowlrc` file, it should be renamed to `.tddairc.yaml`
2. Configuration keys have been reorganized:

```yaml
# Old CodeOwl config
codeowners:
  path: ".github/CODEOWNERS"
  confidence_threshold: 0.8

# New ReelCode config
ownership:
  confidenceThreshold: 0.8
  codeownersPath: ".github/CODEOWNERS"
```

### From AI Coding Assistant

1. If you have a `.llmclirc.yaml` file, it should be renamed to `.tddairc.yaml`
2. Configuration keys remain mostly the same:

```yaml
# Old AI Coding Assistant config
analysis:
  maxFileSize: 1000000
  
# New ReelCode config (same structure)
analysis:
  maxFileSize: 1000000
```

## API Migration

### From CodeOwl

```javascript
// Old CodeOwl API
const { analyzeRepository, optimizeCodeowners } = require('@bluefly/codeowl');

// New ReelCode API
const { OwnershipAnalyzer, CodeOwnersOptimizer } = require('@bluefly/tddai');
const ownershipAnalyzer = OwnershipAnalyzer.getInstance();
const codeownersOptimizer = CodeOwnersOptimizer.getInstance();
```

### From AI Coding Assistant

```javascript
// Old AI Coding Assistant API
import { CodeAnalyzer, TestGenerator } from '@bluefly/ai-coding-assistant';

// New ReelCode API (similar pattern)
import { CodeAnalyzer, TestGenerator } from '@bluefly/tddai';
```

## CI/CD Integration Migration

### From CodeOwl

```yaml
# Old GitLab CI integration
include:
  - component: /path/to/codeowl/ci/codeowl-ci-integration.yml
    inputs:
      codeowners_path: ".github/CODEOWNERS"

# New ReelCode integration
include:
  - component: /path/to/tddai/ci/tddai-ci-integration.yml
    inputs:
      codeowners_path: ".github/CODEOWNERS"
      # Plus additional options for code analysis
      analysis_level: "normal"
```

### From AI Coding Assistant

```yaml
# Old GitLab CI integration
validate:
  stage: validate
  script:
    - npm install -g @bluefly/ai-coding-assistant
    - llmcli validate .

# New ReelCode integration
validate:
  stage: validate
  script:
    - npm install -g @bluefly/tddai
    - tddai validate .
```

## FAQ

### Why were these tools merged?

The tools had complementary functionality but significant infrastructure overlap. Merging them provides a more powerful, comprehensive developer toolkit while reducing maintenance overhead.

### Will the old tools continue to be supported?

Both CodeOwl and AI Coding Assistant will receive critical updates for 6 months, but no new features. We recommend migrating to ReelCode for continued support and new features.

### Is ReelCode backward compatible?

ReelCode maintains most API patterns from both tools, but some changes were necessary to unify the functionality. This migration guide covers all the key differences.

### How do I report issues or request features?

Please use the ReelCode issue tracker at [https://gitlab.bluefly.io/bluefly/tddai/issues](https://gitlab.bluefly.io/bluefly/tddai/issues) for all issues and feature requests.

### Can I use ReelCode with my existing CI/CD pipelines?

Yes, but you'll need to update your CI/CD configurations as outlined in the [CI/CD Integration Migration](#cicd-integration-migration) section above.

---

If you have any questions not covered by this guide, please contact [support@bluefly.io](mailto:support@bluefly.io) for assistance.