# Getting Started with AI Coding Standards Tool

This guide will help you quickly set up and start using the AI Coding Standards Tool in your project.

## Installation

You can install the AI Coding Standards Tool either globally or as a project dependency:

### Global Installation

```bash
npm install -g @bluefly/ai-coding-standards
```

This allows you to use the `acs` command from anywhere on your system.

### Project Installation

```bash
npm install --save-dev @bluefly/ai-coding-standards
```

With this approach, you can run the tool using npx:

```bash
npx acs <command>
```

## Quick Start

### 1. Initialize Standards Configuration

First, initialize a standards configuration in your project:

```bash
acs init
```

This will create a `.acs-standards.json` file in your project root with default settings.

### 2. Customize Your Standards

Edit the generated `.acs-standards.json` file to match your project's requirements:

```json
{
  "standards": {
    "javascript": {
      "extends": ["airbnb-base"],
      "rules": {
        "max-len": ["error", { "code": 100 }],
        "ai-assisted": {
          "documentation": "required",
          "testCoverage": 90
        }
      }
    }
  },
  "aiAssistants": {
    "configurePrompts": true,
    "assistants": ["claude", "copilot"]
  },
  "analysis": {
    "ignorePatterns": ["node_modules/**", "dist/**"]
  }
}
```

### 3. Analyze Your Code

Run a standards analysis on your project:

```bash
acs analyze .
```

This will generate a report showing compliance with your defined standards.

### 4. Integrate with AI Assistants

Generate AI assistant configurations:

```bash
acs generate:ai-config
```

This creates configuration files for your selected AI assistants, incorporating your coding standards.

### 5. Setup CI Integration

For continuous standards enforcement, add the tool to your CI pipeline:

```bash
acs generate:ci-config
```

This will generate configuration files for common CI systems (GitHub Actions, GitLab CI, etc.).

## Basic Commands

Here are the most commonly used commands:

| Command | Description |
|---------|-------------|
| `acs init` | Initialize standards configuration |
| `acs analyze [path]` | Analyze code against standards |
| `acs validate:prompts [path]` | Validate AI prompts against standards |
| `acs generate:tests [path]` | Generate standards-compliant test templates |
| `acs generate:ai-config` | Generate AI assistant configurations |
| `acs generate:ci-config` | Generate CI integration configurations |
| `acs report` | Generate compliance reports |

## Next Steps

Now that you have the basics set up, you might want to explore:

- [Standards Configuration](standards/configuration.md) - Customize your coding standards
- [AI Assistant Integration](ai-integration/overview.md) - Integrate with Claude, Copilot, and other AI assistants
- [Custom Rules](development/custom-rules.md) - Create project-specific rules
- [CI/CD Integration](tutorials/ci-integration.md) - Set up continuous standards enforcement

## Troubleshooting

If you encounter issues during setup:

- Ensure you have Node.js version 16 or higher installed
- Check that your project's package.json is valid
- Verify that you have appropriate permissions in your project directory
- For detailed error information, run commands with the `--verbose` flag

For more help, see our [FAQ](faq.md) or [open an issue](https://github.com/bluefly/ai-coding-standards/issues) on GitHub.