---
id: reference-cli-commands
---
# Common Development Commands

## Build & Development Commands
```bash
# Navigate to a specific project directory first
cd [project_directory]

# Start development server
npm run dev

# Build project (specific service only)
npm run build

# Watch for changes during development
npm run build:watch

# Production build
npm run build:prod

# Start production server
npm run start
```

## Testing Commands
```bash
# Navigate to a specific project directory first
cd [project_directory]

# Run all tests for the specific project
npm test

# Watch tests during development
npm run test:watch

# Generate test coverage report
npm run test:coverage

# Run unit tests only
npm run test:unit

# Run integration tests
npm run test:integration

# Run tests in CI environment
npm run test:ci

# Drupal PHPUnit tests (llm_platform_recipe)
cd llm_platform_recipe
./vendor/bin/phpunit

# Run specific Drupal test categories
./vendor/bin/phpunit tests/src/Unit/
./vendor/bin/phpunit tests/src/Kernel/
./vendor/bin/phpunit tests/src/Functional/
```

## Linting & Formatting
```bash
# Navigate to a specific project directory first
cd [project_directory]

# Run linter
npm run lint

# Fix linting issues
npm run lint:fix

# Format code with Prettier
npm run format

# Check formatting without changing files
npm run format:check

# Run TypeScript type checker
npm run typecheck
```

## CI & Validation
```bash
# Navigate to a specific project directory first
cd [project_directory]

# Run full CI pipeline (lint, typecheck, test, build)
npm run ci

# Run multiple validation steps
npm run validate

# Validate OpenAPI specifications
npm run openapi:validate
```

## Docker & Kubernetes
```bash
# Build Docker container for a specific service
cd [project_directory]
npm run docker:build

# Deploy specific service to Kubernetes
npm run helm:upgrade
```

## Drupal Recipe Commands
```bash
# Navigate to the llm_platform_recipe directory
cd llm_platform_recipe

# Apply the LLM Platform recipe
drush recipe:apply llm_platform

# Configure AI providers
drush config:set llm_platform_recipe.providers openai_api_key "your-key"

# Set up health monitoring
drush config:set llm_platform_recipe.health_monitor interval 30

# Enable real-time features
drush config:set llm_platform_recipe.realtime websocket_enabled true
```
