---
id: scripts-docgen-claude-README
---
# Claude Documentation Generator

This collection of scripts automates the creation and maintenance of documentation for the LLM Platform AI Platform, with a focus on CLAUDE.md integration and specialized documentation needs such as database schemas and API documentation.

## Features

### Main Script (docgen-claude.js)
- Create new documentation files from templates (standard, architecture, database schema, API)
- Update existing documentation files
- Validate documentation structure
- Sync content from CLAUDE.md to .claude or docs directory
- Update README.md index with categorized documentation links
- Support for both .claude and docs directory structures

### Specialized Scripts
- **simple-db-schema.js**: Create comprehensive database schema documentation
- **simple-api-doc.js**: Create detailed API documentation

These specialized scripts use a simplified approach without template string issues and provide more detailed examples.

## Installation

The script is already integrated with the project's package.json and can be run using npm scripts.

## Usage

```bash
# Using npm scripts (recommended)
npm run docs:create -- filename "Category Name" [template] [location]
npm run docs:update-doc -- filename [location]
npm run docs:validate-claude [location]
npm run docs:sync-claude [location]
npm run docs:index-claude [location]
npm run docs:help

# Database schema documentation (simplified script)
npm run docs:db-schema -- llm_platform "Database Schemas"

# API documentation (simplified script)
npm run docs:api-doc -- model_registry "API Documentation"

# Direct script usage
node scripts/docgen-claude.js <command> [options]
node scripts/simple-db-schema.js [name] [category]
node scripts/simple-api-doc.js [name] [category]
```

### Commands

- `create <name> [category] [template] [location]` - Create a new documentation file
- `update <name> [location]` - Update an existing documentation file
- `validate [location]` - Validate the documentation structure
- `sync [location]` - Sync content from CLAUDE.md to target directory
- `index [location]` - Update the README.md index
- `db-schema <name> [category]` - Create a database schema documentation file
- `api-doc <name> [category]` - Create an API documentation file
- `help` - Show the help message

### Options

- `name` - The name of the documentation file
- `category` - The category for the documentation file
- `template` - The template to use (standard, architecture, db_schema, api)
- `location` - The target location (.claude or docs)

### Examples

```bash
# Create a new documentation file in the "Development Standards" category
npm run docs:create -- api_guidelines "Development Standards"

# Create a new documentation file using the architecture template
npm run docs:create -- service_architecture "Core Documentation" architecture

# Create a database schema documentation file
npm run docs:create -- user_database "Database Schemas" db_schema docs

# Create an API documentation file
npm run docs:create -- user_api "API Documentation" api docs

# Update an existing documentation file
npm run docs:update-doc -- testing_requirements

# Validate the documentation structure in the docs directory
npm run docs:validate-claude docs

# Sync content from CLAUDE.md to docs directory
npm run docs:sync-claude docs

# Update the README.md index in the docs directory
npm run docs:index-claude docs
```

## Templates

The script uses templates from the `scripts/templates` directory:

- `standard.md` - Standard template for general documentation
- `architecture.md` - Specialized template for architecture documentation
- `db_schema.md` - Specialized template for database schema documentation
- `api.md` - Specialized template for API documentation

You can create additional templates by adding new .md files to the templates directory and updating the script if needed.

## Directory Structure Support

The script supports two directory structures:

### .claude Directory Structure

```
.claude/
├── README.md             # Main index with categorized links
├── file1.md              # Documentation files
├── file2.md
└── ...
```

### docs Directory Structure

```
docs/
├── README.md                     # Main index with categories
├── category1/                    # Category directories
│   ├── README.md                 # Category index
│   ├── file1.md                  # Documentation files
│   └── file2.md
├── category2/
│   ├── README.md
│   ├── file3.md
│   └── file4.md
└── ...
```

## Integration with CLAUDE.md

The `sync` command extracts sections from CLAUDE.md and creates individual documentation files in the target directory. It categorizes the files based on content and updates the README.md index accordingly.

## Documentation Categories

The script uses the following categories for organizing documentation:

- Core Documentation - Architecture, structure, commands
- Development Standards - Testing, TDD, API guidelines
- DevOps & Operations - Pipelines, deployment, monitoring
- Implementation Details - Drupal, modules, fields
- Reference & Support - Glossary, vision, troubleshooting
- Database Schemas - Database structure, tables, relationships
- API Documentation - API endpoints, parameters, responses

## Best Practices

1. Use `npm run docs:create` to create new documentation files
2. Use templates appropriate for the content type (standard, architecture, db_schema, api)
3. Run `npm run docs:validate-claude` regularly to ensure documentation integrity
4. Use `npm run docs:sync-claude` to import content from CLAUDE.md
5. Update documentation metadata with `npm run docs:update-doc` when making changes
6. Use the docs directory structure for organized, categorized documentation
