---
id: scripts-templates-README
---
# Documentation Templates

This directory contains templates for creating new documentation files for the LLM Platform AI Platform.

## Available Templates

### Standard Template (standard.md)

The `standard.md` template provides a consistent structure for general documentation files. It includes:

- Title and overview
- Key components section
- Detailed information section
- Examples with code
- Best practices
- Related documentation links
- References
- Version and status information

### Architecture Template (architecture.md)

The `architecture.md` template provides a specialized structure for architecture documentation. It includes:

- Architecture diagram
- Component responsibilities
- Data flow
- Integration points
- Deployment model
- Security considerations
- Performance characteristics
- Scalability approach
- Monitoring and observability
- Error handling strategy
- Implementation examples
- Configuration

### Database Schema Template (db_schema.md)

The `db_schema.md` template provides a specialized structure for database schema documentation. It includes:

- Entity relationship diagram
- Detailed table definitions
- Column specifications
- Indexes
- Relationships
- Migration considerations
- Query examples
- Performance considerations
- Security considerations

### API Documentation Template (api.md)

The `api.md` template provides a comprehensive structure for API documentation. It includes:

- Base URL and authentication
- Request headers
- Detailed endpoint documentation
- Request and response examples
- Data models
- Error codes
- Rate limiting
- Versioning
- Pagination
- Complete workflow examples
- Best practices

## Template Placeholders

Templates use placeholders that will be replaced when creating new documentation files:

| Placeholder | Description | Example Replacement |
|-------------|-------------|---------------------|
| `{{TITLE}}` | The title of the document | "API Guidelines" |
| `{{TOPIC}}` | The topic of the document | "API design standards" |
| `{{OVERVIEW_PLACEHOLDER}}` | Placeholder for overview content | "Add an overview of this topic here." |
| `{{COMPONENTS_PLACEHOLDER}}` | Placeholder for components content | "- Component 1\n- Component 2\n- Component 3" |
| `{{DETAILS_PLACEHOLDER}}` | Placeholder for detailed information | "Add detailed information here." |
| `{{LANGUAGE}}` | The language for code examples | "javascript" |
| `{{CODE_EXAMPLE_PLACEHOLDER}}` | Placeholder for code examples | "// Add code example here\nconst example = ..." |
| `{{BEST_PRACTICES_PLACEHOLDER}}` | Placeholder for best practices | "1. Best practice 1\n2. Best practice 2" |
| `{{RELATED_DOC_1}}` | Name of related document 1 | "Testing Requirements" |
| `{{RELATED_DOC_1_PATH}}` | Path to related document 1 | "./testing_requirements.md" |
| `{{RELATED_DOC_2}}` | Name of related document 2 | "API Guidelines" |
| `{{RELATED_DOC_2_PATH}}` | Path to related document 2 | "./api_guidelines.md" |
| `{{REFERENCES_PLACEHOLDER}}` | Placeholder for references | "- Reference 1\n- Reference 2" |
| `{{VERSION}}` | Document version | "1.0.0" |
| `{{LAST_UPDATED}}` | Last updated date | "May 31, 2025" |
| `{{STATUS}}` | Document status | "Draft" |

### Database Schema Template Placeholders

| Placeholder | Description |
|-------------|-------------|
| `{{DIAGRAM_PLACEHOLDER}}` | Entity-relationship diagram |
| `{{TABLE1_NAME}}` | Name of the first table |
| `{{TABLE1_DESCRIPTION}}` | Description of the first table |
| `{{TABLE1_COLUMNS}}` | Column definitions for the first table |
| `{{TABLE1_INDEXES}}` | Index definitions for the first table |
| `{{RELATIONSHIPS_PLACEHOLDER}}` | Description of table relationships |
| `{{DATA_FLOW_PLACEHOLDER}}` | Description of data flow |
| `{{MIGRATION_PLACEHOLDER}}` | Migration considerations |
| `{{QUERY_EXAMPLE_PLACEHOLDER}}` | SQL query examples |
| `{{PERFORMANCE_PLACEHOLDER}}` | Performance considerations |
| `{{SECURITY_PLACEHOLDER}}` | Security considerations |

### API Documentation Template Placeholders

| Placeholder | Description |
|-------------|-------------|
| `{{BASE_URL}}` | Base URL for the API |
| `{{AUTHENTICATION_PLACEHOLDER}}` | Authentication description |
| `{{HEADERS_PLACEHOLDER}}` | Request headers |
| `{{ENDPOINT1_NAME}}` | Name of the first endpoint |
| `{{ENDPOINT1_DESCRIPTION}}` | Description of the first endpoint |
| `{{ENDPOINT1_URL}}` | URL of the first endpoint |
| `{{ENDPOINT1_METHOD}}` | HTTP method of the first endpoint |
| `{{ENDPOINT1_AUTH_REQUIRED}}` | Authentication requirement |
| `{{ENDPOINT1_REQUEST_PARAMS_TYPE}}` | Type of request parameters |
| `{{ENDPOINT1_REQUEST_PARAMS}}` | Request parameters |
| `{{ENDPOINT1_SUCCESS_CODE}}` | Success response code |
| `{{ENDPOINT1_SUCCESS_RESPONSE}}` | Success response |
| `{{MODEL1_NAME}}` | Name of the first data model |
| `{{MODEL1_DESCRIPTION}}` | Description of the first data model |
| `{{MODEL1_SCHEMA}}` | Schema definition of the first data model |
| `{{ERROR_CODES_PLACEHOLDER}}` | Error codes |
| `{{RATE_LIMITING_PLACEHOLDER}}` | Rate limiting information |
| `{{VERSIONING_PLACEHOLDER}}` | API versioning information |
| `{{PAGINATION_PLACEHOLDER}}` | Pagination information |
| `{{WORKFLOW_EXAMPLE_PLACEHOLDER}}` | Complete workflow example |

## Creating Custom Templates

To create a custom template:

1. Create a new Markdown file in this directory (e.g., `custom_template.md`)
2. Define your template structure with appropriate placeholders
3. Update the `docgen-claude.js` script to use your new template for specific types of documentation

## Using Templates

Templates are used by the `docgen-claude.js` script when creating new documentation files:

```bash
# Using npm scripts with the main docgen-claude.js
npm run docs:create -- component_architecture "Core Documentation"
npm run docs:create -- user_database "Database Schemas" db_schema
npm run docs:create -- user_api "API Documentation" api

# Using specialized scripts for database and API docs
npm run docs:db-schema -- llm_platform "Database Schemas"
npm run docs:api-doc -- model_registry "API Documentation"
```

This will create new documentation files based on the appropriate templates. For database schemas and API documentation, we recommend using the specialized scripts (`simple-db-schema.js` and `simple-api-doc.js`) which provide more comprehensive examples.
