// @ts-check
// Note: type annotations allow type checking and IDEs autocompletion

/** @type {import('@docusaurus/types').Config} */
const config = {
  title: 'LLM Platform Documentation',
  tagline: 'Comprehensive Documentation for the Enterprise AI Integration Platform',
  favicon: 'img/favicon.ico',

  // Set the production url of your site here
  url: 'https://llm-docs.bluefly.io',
  // Set the /<baseUrl>/ pathname under which your site is served
  baseUrl: '/',

  // GitLab pages deployment config
  organizationName: 'bluefly',
  projectName: 'llm-docs',

  onBrokenLinks: 'warn',
  onBrokenMarkdownLinks: 'warn',

  i18n: {
    defaultLocale: 'en',
    locales: ['en'],
  },

  presets: [
    [
      'classic',
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: {
          sidebarPath: require.resolve('./sidebars.js'),
          routeBasePath: '/', // Docs at root
          editUrl: 'https://gitlab.bluefly.io/llm/llm-docs/-/edit/main/',
          exclude: [
            '**/__DELETE_LATER/**',
            '**/venv/**',
            '**/node_modules/**',
            '**/demo_consolidated/**',
            '**/move_consolidated/**',
            '**/*.test.md',
            '**/planning/INNOVATION_ROADMAP_SLIDES.md',
            '**/planning/ENHANCED_INNOVATION_ROADMAP.md',
            '**/platform-deployment-status.md',
            '**/development/tdd/enforcement.md',
            '**/modules/development/drupal_migration_plus/ATTRIBUTION.md',
            '**/modules/development/drupal_migration_plus/FIELD_MAPPING_TUTORIAL.md',
            '**/modules/development/langchain/BENCHMARKS.md',
            '**/modules/development/native_ai/SETTINGS_FORM_UI.md',
            '**/packages/development/bfapiclient/README.md',
            '**/operations/documentation-consolidation.md',
            '**/components/bluefly_insights/INTEGRATION.md',
            // Exclude problematic aggregated files with MDX parsing errors
            '**/cicd/bfcicomponents/CHANGELOG.md',
            '**/cicd/bfcicomponents/TROUBLESHOOTING.md',
            '**/cicd/bfcicomponents/api.md',
            '**/cicd/bfcicomponents/api/bfapi-roadmap.md',
            '**/cicd/bfcicomponents/api/bfapiclient-roadmap.md',
            '**/cicd/bfcicomponents/architecture/bfcicomponents-roadmap.md',
            '**/cicd/bfcicomponents/archive/**',
            '**/cicd/bfcicomponents/components/terraform-deploy/**',
            '**/cicd/bfcicomponents/components/todo-aggregator/**',
            '**/cicd/bfcicomponents/development/CLAUDE.md',
            '**/cicd/bfcicomponents/guide/support.md',
            '**/cicd/bfcicomponents/planning/**',
            '**/cicd/bfcicomponents/semantic-release.md',
            '**/packages/*/package-info.md',
            '**/packages/bfrfp/api.md',
            '**/packages/bfrfp/api/api-reference.md',
            '**/packages/bfrfp/archive/AI_README.md',
            '**/packages/bfrfp/ml/ML_INTEGRATION.md',
            '**/packages/llm-gateway-sdk/README.md',
            '**/packages/llm-gateway/README.md',
            '**/packages/llm-mcp/architecture/mcp-config.md',
            '**/packages/llm-mcp/mcp-servers/**',
            '**/packages/llm-mcp/performance/performance-tuning.md',
            '**/packages/llm-ui/README.md',
            '**/packages/llm-ui/accessible-components.md',
            '**/packages/llm-ui/api/accessibility-api.md',
            '**/packages/tddai/src/ci/**/templates/**',
            // Exclude files with MDX parsing errors
            '**/packages/secure-project/API_REFERENCE.md',
            '**/packages/secure-project/README.md',
            // Exclude README files where index.md already exists to prevent duplicates
            '**/models/tddai-model/README.md',
            '**/packages/bfrfp/README.md',
            '**/packages/llm-mcp/README.md',
            '**/packages/llm-ui/README.md',
            '**/cicd/bfcicomponents/README.md',
          ],
        },
        blog: false, // Disable blog
        theme: {
          customCss: require.resolve('./src/css/custom.css'),
        },
      }),
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      // Replace with your project's social card
      image: 'img/docusaurus-social-card.jpg',
      navbar: {
        title: 'LLM Platform',
        logo: {
          alt: 'LLM Platform Logo',
          src: 'img/logo.png',
          href: '/',
          target: '_self',
        },
        items: [
          {
            to: 'platform-architecture',
            label: 'Architecture',
            position: 'left',
          },
          {
            to: 'INTEGRATION',
            label: 'Integration',
            position: 'left',
          },
          {
            to: 'TESTING',
            label: 'Testing',
            position: 'left',
          },
          {
            type: 'dropdown',
            label: 'Packages',
            position: 'left',
            items: [
              {
                to: 'packages/llm-gateway/',
                label: '🚀 LLM Gateway',
              },
              {
                to: 'packages/llm-gateway-sdk/',
                label: '🔗 Gateway SDK',
              },
              {
                to: 'packages/llm-mcp/',
                label: '🤖 MCP Server',
              },
              {
                to: 'packages/apple-fm/',
                label: '🍎 Apple Foundation Models',
              },
              {
                to: 'packages/bfrfp/',
                label: '📄 RFP Generator',
              },
              {
                to: 'packages/tddai/',
                label: '🧪 TDD AI Framework',
              },
              {
                to: 'packages/llmcli/',
                label: '⚡ CLI Tools',
              },
              {
                to: 'packages/llm-ui/',
                label: '🎨 UI Components',
              },
              {
                to: 'packages/secure-project/',
                label: '🔒 Security Project',
              },
              {
                to: 'cicd/bfcicomponents/',
                label: '🔧 CI/CD Components',
              },
              {
                to: 'models/tddai-model/',
                label: '🤖 TDDAI Model',
              },
            ],
          },
          {
            href: 'https://gitlab.bluefly.io/llm',
            label: 'GitLab',
            position: 'right',
          },
        ],
      },
      footer: {
        style: 'dark',
        links: [
          {
            title: 'Documentation',
            items: [
              {
                label: 'Architecture',
                to: 'platform-architecture',
              },
              {
                label: 'Integration Guide',
                to: 'INTEGRATION',
              },
              {
                label: 'Testing',
                to: 'TESTING',
              },
            ],
          },
          {
            title: 'NPM Packages',
            items: [
              {
                label: 'apple-fm - Foundation Models',
                to: 'packages/apple-fm/',
              },
              {
                label: 'llmcli - CLI Tool',
                to: 'packages/llmcli/',
              },
              {
                label: 'llm-gateway - API Gateway',
                to: 'packages/llm-gateway/',
              },
              {
                label: 'tddai - TDD Framework',
                to: 'packages/tddai/',
              },
            ],
          },
          {
            title: 'GitLab Repositories',
            items: [
              {
                label: 'LLM Platform',
                href: 'https://gitlab.bluefly.io/llm',
              },
              {
                label: 'CI/CD Components',
                href: 'https://gitlab.bluefly.io/llm/bfcicomponents',
              },
              {
                label: 'Documentation Hub',
                href: 'https://gitlab.bluefly.io/llm/llm-docs',
              },
            ],
          },
        ],
        copyright: `Copyright © ${new Date().getFullYear()} LLM Platform. Built with Docusaurus.`,
      },
      prism: {
        theme: require('prism-react-renderer').themes.github,
        darkTheme: require('prism-react-renderer').themes.dracula,
        additionalLanguages: ['php', 'bash', 'json', 'yaml'],
      },
    }),
};

module.exports = config;