const express = require('express');
const router = express.Router();
const jwt = require('jsonwebtoken');
const { jwtSecret, jwtExpiresIn } = require('../config/auth');
const { authLimiter } = require('../middleware/rateLimit');
const logger = require('../utils/logger');

// POST /auth - Get JWT token
router.post('/', authLimiter, async (req, res, next) => {
  try {
    const { username, password } = req.body;
    
    // In a real application, validate the credentials against a database
    // This is a simplified example for demo purposes
    if (!username || !password) {
      return res.status(400).json({
        error: 'bad_request',
        message: 'Username and password are required'
      });
    }
    
    // Simple validation for demonstration
    if (username === 'user@example.com' && password === 'secure_password') {
      // Create JWT token
      const token = jwt.sign(
        { 
          id: 1, 
          email: username,
          role: 'admin'
        },
        jwtSecret,
        { expiresIn: jwtExpiresIn }
      );
      
      logger.info(`Authentication successful for user ${username}`);
      
      return res.status(200).json({ token });
    } else {
      logger.warn(`Authentication failed for user ${username}`);
      
      return res.status(401).json({
        error: 'unauthorized',
        message: 'Invalid username or password'
      });
    }
  } catch (error) {
    next(error);
  }
});

module.exports = router;