const express = require('express');
const router = express.Router();
const deploymentController = require('../controllers/deploymentController');
const { authenticate } = require('../middleware/auth');
const { standardLimiter, bulkLimiter } = require('../middleware/rateLimit');
const { validate } = require('../middleware/validation');

// Apply authentication and rate limiting to all routes
router.use(authenticate, standardLimiter);

// POST /deployments - Create a new deployment
router.post(
  '/',
  bulkLimiter, // Apply stricter rate limit for creation operations
  validate('createDeployment'),
  deploymentController.createDeployment
);

// GET /deployments - List deployments with optional filtering
router.get('/', deploymentController.getDeployments);

// GET /deployments/:id - Get a deployment by ID
router.get('/:id', deploymentController.getDeploymentById);

module.exports = router;